@@ -37,7 +37,7 @@ from ..utils.file_utils import pytorch_available, tensorpack_available, tf_avail
 from ..utils.fs import mkdir_p
 from ..utils.logger import logger
 from ..utils.metacfg import AttrDict, set_config_by_yaml
-from ..utils.settings import names
+from ..utils.settings import CellType, LayoutType
 from ..utils.systools import get_configs_dir_path, get_package_path
 
 if tf_available() and tensorpack_available():
@@ -52,7 +52,7 @@ if pytorch_available():
     from ..extern.d2detect import D2FrcnnDetector
 
 
-__all__ = ["get_dd_analyzer"]
+__all__ = ["get_dd_analyzer", "build_analyzer"]
 
 _DD_ONE = "deepdoctection/configs/conf_dd_one.yaml"
 _TESSERACT = "deepdoctection/configs/conf_tesseract.yaml"
@@ -65,21 +65,17 @@ def _auto_select_lib_and_device() -> Tuple[str, str]:
     If TF is available, use TF unless a GPU is not available, in which case choose PT. If CUDA is not available and PT
     is not installed raise ImportError.
     """
-    if tf_available():
+    if tf_available() and tensorpack_available():
         if get_num_gpu() >= 1:
             return "tf", "cuda"
         if pytorch_available():
             return "pt", "cpu"
-        raise ImportError("No GPU is available. You must install Pytorch in order to run on a CPU")
+        raise ModuleNotFoundError("Install Pytorch and Torchvision to run with a CPU")
     if pytorch_available():
         if cuda.is_available():
             return "pt", "gpu"
         return "pt", "cpu"
-    raise ImportError(
-        "Neither Pytorch nor Tensorflow are installed. You must install at least one of them before "
-        "running the analyzer. Note, that if no GPU is available you can only use Detectron2 along "
-        "with Pytorch."
-    )
+    raise ModuleNotFoundError("Install Tensorflow or Pytorch before building analyzer")
 
 
 def _maybe_copy_config_to_cache(file_name: str) -> str:
@@ -155,10 +151,10 @@ def build_analyzer(cfg: AttrDict) -> DoctectionPipe:
             assert categories_item is not None
             d_item = D2FrcnnDetector(item_config_path, item_weights_path, categories_item, device=cfg.DEVICE)
 
-        cell = SubImageLayoutService(d_cell, names.C.TAB, {1: 6}, True)
+        cell = SubImageLayoutService(d_cell, LayoutType.table, {1: 6}, True)
         pipe_component_list.append(cell)
 
-        item = SubImageLayoutService(d_item, names.C.TAB, {1: 7, 2: 8}, True)
+        item = SubImageLayoutService(d_item, LayoutType.table, {1: 7, 2: 8}, True)
         pipe_component_list.append(item)
 
         table_segmentation = TableSegmentationService(
@@ -191,7 +187,7 @@ def build_analyzer(cfg: AttrDict) -> DoctectionPipe:
 
         match = MatchingService(
             parent_categories=cfg.WORD_MATCHING.PARENTAL_CATEGORIES,
-            child_categories=names.C.WORD,
+            child_categories=LayoutType.word,
             matching_rule=cfg.WORD_MATCHING.RULE,
             threshold=cfg.WORD_MATCHING.IOU_THRESHOLD
             if cfg.WORD_MATCHING.RULE in ["iou"]
@@ -200,9 +196,16 @@ def build_analyzer(cfg: AttrDict) -> DoctectionPipe:
         pipe_component_list.append(match)
 
         order = TextOrderService(
-            text_container=names.C.WORD,
-            floating_text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST],
-            text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST, names.C.CELL, names.C.HEAD, names.C.BODY],
+            text_container=LayoutType.word,
+            floating_text_block_names=[LayoutType.title, LayoutType.text, LayoutType.list],
+            text_block_names=[
+                LayoutType.title,
+                LayoutType.text,
+                LayoutType.list,
+                LayoutType.cell,
+                CellType.header,
+                CellType.body,
+            ],
         )
         pipe_component_list.append(order)
 
@@ -260,26 +263,7 @@ def get_dd_analyzer(
     cfg.LANG = language
     cfg.freeze()
 
-    logger.info("Deep Doctection Analyzer Config: ------------------------------------------\n %s", str(cfg))
-
-    logger.info(
-        "Building the Analyzer pipeline. This includes layout analysis with detection of titles, text, lists "
-        "tables and figures."
-    )
-
-    if cfg.TAB:
-        logger.info(
-            "As tables have been chosen, a table recognition system will be invoked. This means, "
-            "that the interior of each detected table will be segmented into cells, rows and column and every "
-            "cell will be labeled with its row and column position as well as its spans."
-        )
-
-    if cfg.OCR:
-        logger.info(
-            " OCR will be performed and each words will be assigned to the detected layout "
-            "compartment, if possible. Finally, words will be stringed together according to its"
-            " reading order."
-        )
+    logger.info("Config: \n %s", str(cfg), cfg.to_dict())
 
     # will silent all TP loggings while building the tower
     if tensorpack_available():
