@@ -22,12 +22,12 @@ Module for tools around processing documents with Pipelines.
 import json
 import os
 
-from dataflow.dataflow import DataFlow, MapData
-
+from ..dataflow.base import DataFlow
+from ..dataflow.common import MapData
 from ..dataflow.custom_serialize import SerializerJsonlines
 from ..datapoint.page import Page
 from ..utils.detection_types import Pathlike
-from ..utils.fs import is_file_extension
+from ..utils.utils import is_file_extension
 
 
 def load_page(path: Pathlike) -> Page:
@@ -45,7 +45,7 @@ def load_page(path: Pathlike) -> Page:
     with open(path, "r", encoding="UTF-8") as file:
         page_dict = json.load(file)
 
-    return Page.from_dict(page_dict)
+    return Page.from_dict(**page_dict)
 
 
 def load_document(path: Pathlike) -> DataFlow:
@@ -55,7 +55,7 @@ def load_document(path: Pathlike) -> DataFlow:
     :param path: Path to a .jsonl file
     :return: DataFlow
     """
-
+    df: DataFlow
     df = SerializerJsonlines.load(path)
     df = MapData(df, Page.from_dict)
     return df
