@@ -4,28 +4,19 @@
 """
 Dataflow is the package of choice for loading and processing data in both training and prediction environments. Dataflow
 is essentially pure Python and, with a simple API, contains a variety of methods for parallelling complex
-transformations. Further information can be found in the excellent documentation:
+transformations. Due to the fact that DataFlow is not available through pypi we have integrated the most important
+DataFlow classes into deepdoctection in order to avoid installing the package separately from source.
+
+Further information (including several tutorials about performance) can be found in the excellent documentation:
 
 https://tensorpack.readthedocs.io/en/latest/tutorial/dataflow.html
-
-To make it easier to use, we re-import dataflow into the package of the same name.
 """
 
-from dataflow.dataflow import (
-    ConcatData,
-    DataFlow,
-    DataFromIterable,
-    DataFromList,
-    JoinData,
-    MapData,
-    MapDataComponent,
-    MultiProcessMapData,
-    MultiThreadMapData,
-    ProxyDataFlow,
-    RepeatedData,
-)
 
+from .base import *
 from .common import *
 from .custom import *
 from .custom_serialize import *
+from .parallel_map import *
+from .serialize import *
 from .stats import *
