@@ -25,16 +25,15 @@ import os
 from collections import defaultdict
 from typing import DefaultDict, Dict, List, Optional, Sequence, Union
 
-from dataflow.dataflow import DataFlow, JoinData, MapData
 from jsonlines import Reader, Writer
 
 from ..utils.context import timed_operation
 from ..utils.detection_types import JsonDict, Pathlike
-from ..utils.fs import is_file_extension
-from ..utils.logger import logger
 from ..utils.pdf_utils import PDFStreamer
 from ..utils.tqdm import get_tqdm
-from .common import FlattenData
+from ..utils.utils import FileExtensionError, is_file_extension
+from .base import DataFlow
+from .common import FlattenData, JoinData, MapData
 from .custom import CacheData, CustomDataFromIterable, CustomDataFromList
 
 __all__ = ["SerializerJsonlines", "SerializerFiles", "SerializerCoco", "SerializerPdfDoc", "SerializerTabsepFiles"]
@@ -87,17 +86,14 @@ class SerializerJsonlines:
         :param max_datapoints: maximum number of datapoint to consider writing to a file.
         """
 
-        assert os.path.isdir(path), f"not a dir {path}"
-        assert is_file_extension(file_name, ".jsonl")
+        if not os.path.isdir(path):
+            raise NotADirectoryError(path)
+        if not is_file_extension(file_name, ".jsonl"):
+            raise FileExtensionError(f"Expected .jsonl file got {path}")
 
+        df.reset_state()
         with open(os.path.join(path, file_name), "w") as file:  # pylint: disable=W1514
             writer = Writer(file)
-            length = _reset_df_and_get_length(df)
-            if length == 0:
-                logger.info("cannot estimate length of dataflow")
-            if max_datapoints is not None:
-                if max_datapoints < length:
-                    logger.info("dataflow larger than max_datapoints")
             for k, dp in enumerate(df):
                 if max_datapoints is None:
                     writer.write(dp)
@@ -122,7 +118,7 @@ class SerializerTabsepFiles:
     """
 
     @staticmethod
-    def load(path: Pathlike, max_datapoins: Optional[int] = None) -> CustomDataFromIterable:
+    def load(path: Pathlike, max_datapoins: Optional[int] = None) -> CustomDataFromList:
         """
         :param path: a path to a .txt file.
         :param max_datapoins: Will stop the iteration once max_datapoints have been streamed
@@ -131,8 +127,8 @@ class SerializerTabsepFiles:
         """
 
         with open(path, "r", encoding="UTF-8") as file:
-            iterator = file.readlines()
-        return CustomDataFromIterable(iterator, max_datapoints=max_datapoins)
+            file_list = file.readlines()
+        return CustomDataFromList(file_list, max_datapoints=max_datapoins)
 
     @staticmethod
     def save(df: DataFlow, path: Pathlike, file_name: str, max_datapoints: Optional[int] = None) -> None:
@@ -147,16 +143,12 @@ class SerializerTabsepFiles:
         :param max_datapoints: maximum number of datapoint to consider writing to a file.
         """
 
-        assert os.path.isdir(path), f"not a dir {path}"
-        assert is_file_extension(file_name, ".txt")
+        if not os.path.isdir(path):
+            raise NotADirectoryError(path)
+        if not is_file_extension(file_name, ".jsonl"):
+            raise FileExtensionError(f"Expected .txt file got {path}")
 
         with open(os.path.join(path, file_name), "w", encoding="UTF-8") as file:
-            length = _reset_df_and_get_length(df)
-            if length == 0:
-                logger.info("cannot estimate length of dataflow")
-            if max_datapoints is not None:
-                if max_datapoints < length:
-                    logger.info("dataflow larger than max_datapoints")
             for k, dp in enumerate(df):
                 if max_datapoints is None:
                     file.write(dp)
@@ -191,6 +183,11 @@ class SerializerFiles:
         :param sort: If set to "True" it will sort all selected files by its string
         :return: dataflow to iterate from
         """
+        df: DataFlow
+        df1: DataFlow
+        df2: DataFlow
+        df3: DataFlow
+
         if shuffle:
             sort = False
         it1 = os.walk(path, topdown=False)
@@ -249,7 +246,8 @@ class CocoParser:
             with timed_operation(message="Loading annotations to memory"):
                 with open(annotation_file, "r", encoding="UTF-8") as file:
                     dataset = json.load(file)
-                assert isinstance(dataset, dict), f"annotation file format {type(dataset)} not supported"
+                if not isinstance(dataset, dict):
+                    raise TypeError(f"Annotation file format {type(dataset)} for {annotation_file} not supported")
             self.dataset = dataset
             self._create_index()
 
@@ -480,9 +478,11 @@ class SerializerCoco:
         :param path: a path to a .json file.
         :return: dataflow to iterate from
         """
-        assert os.path.isfile(path), path
+        if not os.path.isfile(path):
+            raise FileNotFoundError(path)
         file = os.path.split(path)[1]
-        assert is_file_extension(file, ".json"), file
+        if not is_file_extension(file, ".json"):
+            raise FileExtensionError(f"Expected .json file got {path}")
 
         with timed_operation("Start loading .json file and serializing"):
             coco = CocoParser(path)
@@ -535,6 +535,7 @@ class SerializerPdfDoc:
 
         file_name = os.path.split(path)[1]
         prefix, suffix = os.path.splitext(file_name)
+        df: DataFlow
         df = CustomDataFromIterable(PDFStreamer(path=path), max_datapoints=max_datapoints)
         df = MapData(df, lambda dp: {"path": path, "file_name": prefix + f"_{dp[1]}" + suffix, "pdf_bytes": dp[0]})
         return df
@@ -553,7 +554,8 @@ class SerializerPdfDoc:
         """
         if path_target is None:
             path_target, _ = os.path.split(path)
-        assert os.path.isdir(path_target), f"not a dir {path_target}"
+        if not os.path.isdir(path_target):
+            raise NotADirectoryError(path)
         df = SerializerPdfDoc.load(path, max_datapoint)
         for dp in df:
             with open(os.path.join(path_target, dp["file_name"]), "wb") as page:
