@@ -27,6 +27,7 @@ from numpy import uint8
 
 from ..utils.detection_types import ImageType
 from ..utils.identifier import get_uuid, is_uuid_like
+from ..utils.settings import ObjectTypes, get_type
 from .annotation import Annotation, BoundingBox, ImageAnnotation, SummaryAnnotation
 from .box import crop_box_from_image, global_to_local_coords, intersection_box
 from .convert import as_dict, convert_b64_to_np_array, convert_np_array_to_b64, convert_pdf_bytes_to_np_array_v2
@@ -83,7 +84,7 @@ class Image:
     embeddings: Dict[str, BoundingBox] = field(default_factory=dict, init=False, repr=True)
     annotations: List[ImageAnnotation] = field(default_factory=list, init=False, repr=True)
     _annotation_ids: List[str] = field(default_factory=list, init=False, repr=False)
-    summary: Optional[SummaryAnnotation] = field(default=None, init=False, repr=False)
+    _summary: Optional[SummaryAnnotation] = field(default=None, init=False, repr=False)
 
     def __post_init__(self) -> None:
         if self.external_id is not None:
@@ -110,7 +111,7 @@ class Image:
         image_id setter
         """
         if self._image_id is not None:
-            raise AssertionError("image_id already defined and cannot be reset")
+            raise ValueError("image_id already defined and cannot be reset")
         if is_uuid_like(input_id):
             self._image_id = input_id
         elif isinstance(input_id, property):
@@ -146,11 +147,24 @@ class Image:
             self.set_width_height(self._image.shape[1], self._image.shape[0])
             self._self_embedding()
         else:
-            assert isinstance(image, np.ndarray), f"cannot load image is of type: {type(image)}"
+            if not isinstance(image, np.ndarray):
+                raise TypeError(f"Cannot load image is of type: {type(image)}")
             self._image = image.astype(uint8)
             self.set_width_height(self._image.shape[1], self._image.shape[0])
             self._self_embedding()
 
+    @property
+    def summary(self) -> Optional[SummaryAnnotation]:
+        """summary"""
+        return self._summary
+
+    @summary.setter
+    def summary(self, summary_annotation: SummaryAnnotation) -> None:
+        """summary setter"""
+        if summary_annotation._annotation_id is None:  # pylint: disable=W0212
+            summary_annotation.annotation_id = self.define_annotation_id(summary_annotation)
+        self._summary = summary_annotation
+
     @property
     def pdf_bytes(self) -> Optional[bytes]:
         """
@@ -258,7 +272,8 @@ class Image:
         :param image_id: A uuid of the embedding image.
         :param bounding_box: bounding box of this image in terms of the embedding image.
         """
-        assert isinstance(bounding_box, BoundingBox), "bounding box must be of type BoundingBox"
+        if not isinstance(bounding_box, BoundingBox):
+            raise TypeError(f"Bounding box must be of type BoundingBox, is of type {type(bounding_box)}")
         self.embeddings[image_id] = bounding_box
 
     def get_embedding(self, image_id: str) -> BoundingBox:
@@ -273,7 +288,6 @@ class Image:
 
     def _self_embedding(self) -> None:
         if self._bbox is not None:
-            assert isinstance(self.image_id, str)
             self.set_embedding(self.image_id, self._bbox)
 
     def dump(self, annotation: ImageAnnotation) -> None:
@@ -284,21 +298,21 @@ class Image:
 
         :param annotation: image annotation to store
         """
-        assert isinstance(annotation, ImageAnnotation), (
-            f"Annotation must be of type ImageAnnotation: "
-            f"{annotation.annotation_id} but is of type {str(type(annotation))}"
-        )
+        if not isinstance(annotation, ImageAnnotation):
+            raise TypeError(
+                f"Annotation must be of type ImageAnnotation: "
+                f"{annotation.annotation_id} but is of type {str(type(annotation))}"
+            )
         if annotation._annotation_id is None:  # pylint: disable=W0212
             annotation.annotation_id = self.define_annotation_id(annotation)
-        assert annotation.annotation_id not in self._annotation_ids, (
-            f"Cannot dump annotation with already taken " f"id {annotation.annotation_id}"
-        )
+        if annotation.annotation_id in self._annotation_ids:
+            raise ValueError(f"Cannot dump annotation with already taken " f"id {annotation.annotation_id}")
         self._annotation_ids.append(annotation.annotation_id)
         self.annotations.append(annotation)
 
     def get_annotation(
         self,
-        category_names: Optional[Union[str, Sequence[str]]] = None,
+        category_names: Optional[Union[str, ObjectTypes, Sequence[Union[str, ObjectTypes]]]] = None,
         annotation_ids: Optional[Union[str, Sequence[str]]] = None,
         annotation_types: Optional[Union[str, Sequence[str]]] = None,
     ) -> List[ImageAnnotation]:
@@ -315,7 +329,9 @@ class Image:
         :return: A (possibly empty) list of Annotations
         """
 
-        cat_names = [category_names] if isinstance(category_names, str) else category_names
+        cat_names = [category_names] if isinstance(category_names, (ObjectTypes, str)) else category_names
+        if cat_names is not None:
+            cat_names = [get_type(cat_name) for cat_name in cat_names]
         ann_ids = [annotation_ids] if isinstance(annotation_ids, str) else annotation_ids
         ann_types = [annotation_types] if isinstance(annotation_types, str) else annotation_types
 
@@ -335,9 +351,9 @@ class Image:
 
     def get_annotation_iter(
         self,
-        category_names: Optional[Union[str, List[str]]] = None,
-        annotation_ids: Optional[Union[str, List[str]]] = None,
-        annotation_types: Optional[Union[str, List[str]]] = None,
+        category_names: Optional[Union[str, ObjectTypes, Sequence[Union[str, ObjectTypes]]]] = None,
+        annotation_ids: Optional[Union[str, Sequence[str]]] = None,
+        annotation_types: Optional[Union[str, Sequence[str]]] = None,
     ) -> Iterable[ImageAnnotation]:
         """
         Get annotation as an iterator. Same as :meth:`get_annotation` but returns an iterator instead of a list.
@@ -381,7 +397,6 @@ class Image:
 
         attributes = annotation.get_defining_attributes()
         attributes_values = [str(getattr(annotation, attribute)) for attribute in attributes]
-        assert self.image_id is not None
         return get_uuid(*attributes_values, str(self.image_id))
 
     def remove(self, annotation: ImageAnnotation) -> None:
@@ -408,13 +423,12 @@ class Image:
         """
 
         ann = self.get_annotation(annotation_ids=annotation_id)[0]
-        assert isinstance(
-            ann, ImageAnnotation
-        ), f"Annotation must be of type ImageAnnotation: {annotation_id} but is of type {str(type(ann))}"
 
         new_image = Image(file_name=self.file_name, location=self.location, external_id=annotation_id)
 
-        assert self._bbox is not None and ann.bounding_box is not None
+        if self._bbox is None or ann.bounding_box is None:
+            raise ValueError(f"Bounding box for image and ImageAnnotation ({annotation_id}) must be set")
+
         new_bounding_box = intersection_box(self._bbox, ann.bounding_box, self.width, self.height)
         if new_bounding_box.absolute_coords:
             width = new_bounding_box.width
@@ -428,7 +442,7 @@ class Image:
         if crop_image and self.image is not None:
             new_image.image = crop_box_from_image(self.image, ann.bounding_box, self.width, self.height)
         elif crop_image and self.image is None:
-            raise ValueError("crop_image = 'True' requires self.image to be not None")
+            raise ValueError("crop_image = True requires self.image to be not None")
 
         ann.image = new_image
 
@@ -445,7 +459,8 @@ class Image:
         """
 
         ann = self.get_annotation(annotation_ids=annotation_id)[0]
-        assert ann.image is not None, "adding sub images to annotations requires ann to have an image"
+        if ann.image is None:
+            raise ValueError("When adding sub images to ImageAnnotation then ImageAnnotation.image must not be None")
         assert ann.bounding_box is not None
         box = ann.bounding_box.to_list("xyxy")
         proposals = self.get_annotation(category_names)
@@ -459,7 +474,10 @@ class Image:
         selected_ids = ann_ids[indices]
         sub_images = self.get_annotation(annotation_ids=selected_ids.tolist())
         for sub_image in sub_images:
-            assert sub_image.image is not None
+            if sub_image.image is None:
+                raise ValueError(
+                    "When setting an embedding to ImageAnnotation then ImageAnnotation.image must not " "be None"
+                )
             sub_image.image.set_embedding(
                 annotation_id,
                 global_to_local_coords(
@@ -479,6 +497,8 @@ class Image:
         if highest_hierarchy_only:
             self.remove_image_from_lower_hierachy()
         export_dict = self.as_dict()
+        export_dict["location"] = str(export_dict["location"])
+        export_dict["summary"] = export_dict.pop("_summary")
         if save_image and self.image is not None:
             export_dict["_image"] = convert_np_array_to_b64(self.image)
         return export_dict
