@@ -28,5 +28,5 @@ from .base import *
 from .dataflow_builder import DataFlowBaseBuilder
 from .info import *
 from .instances import *
-from .registry import DatasetRegistry
+from .registry import *
 from .save import *
