@@ -64,7 +64,7 @@ def dataflow_to_json(
         mkdir_p(path / "image")
 
     df = MapData(df, lambda dp: dp.get_export(save_image, highest_hierarchy_only))
-
+    df.reset_state()
     if single_files:
         for idx, dp in enumerate(df):
             if idx == max_datapoints:
@@ -80,5 +80,6 @@ def dataflow_to_json(
                 json.dump(dp, file)
 
     else:
-        assert file_name, "if single_files is set to False must pass a valid file name for .jsonl file"
+        if not file_name:
+            raise ValueError("If single_files is set to False must pass a valid file name for .jsonl file")
         SerializerJsonlines.save(df, path, file_name, max_datapoints)
