@@ -43,8 +43,10 @@ class MetricBase(ABC):
     executed and the results should be saved in separate lists.
     """
 
+    name: str
     metric: Callable[[Any, Any], Optional[Any]]
     mapper: Callable[[Any, Any], Optional[Any]]
+    _results: List[JsonDict]
 
     def __new__(cls, *args, **kwargs):  # type: ignore # pylint: disable=W0613
         requirements = cls.get_requirements()
@@ -121,3 +123,7 @@ class MetricBase(ABC):
             output[new_key[:-1]] = new_val
 
         return output
+
+    @classmethod
+    def print_result(cls) -> None:
+        """Print metric result. Overwrite this method if you want a specific output"""
