@@ -33,11 +33,11 @@ from ..pipe.base import LanguageModelPipelineComponent, PredictorPipelineCompone
 from ..pipe.concurrency import MultiThreadPipelineComponent
 from ..pipe.doctectionpipe import DoctectionPipe
 from ..utils.logger import logger
-from ..utils.settings import names
+from ..utils.settings import DatasetType
 from .base import MetricBase
 
 
-class Evaluator:  # pylint: disable=R0903
+class Evaluator:
     """
     The API for evaluating pipeline components or pipelines on a given dataset. For a given model, a given dataset and
     a given metric, this class will stream the dataset, call the predictor(s) and will evaluate the predictions against
@@ -146,7 +146,6 @@ class Evaluator:  # pylint: disable=R0903
         :return: dict with metric results.
         """
 
-        assert self.dataset.dataflow.categories is not None, "dataset requires dataflow.categories to be not None"
         df_gt = self.dataset.dataflow.build(**dataflow_build_kwargs)
         df_pr = self.dataset.dataflow.build(**dataflow_build_kwargs)
 
@@ -156,6 +155,7 @@ class Evaluator:  # pylint: disable=R0903
 
         logger.info("Starting evaluation...")
         result = self.metric.get_distance(df_gt, df_pr, self.dataset.dataflow.categories)
+        self.metric.print_result()
 
         if output_as_dict:
             return self.metric.result_list_to_dict(result)
@@ -172,10 +172,9 @@ class Evaluator:  # pylint: disable=R0903
             df_pr_list = self.pipe_component.start()
             return DataFromList(df_pr_list)
         df_pr = MapData(df_pr, maybe_load_image)
-        assert self.pipe
-        df_pr = self.pipe.analyze(dataset_dataflow=df_pr, output="image")
+        df_pr = self.pipe.analyze(dataset_dataflow=df_pr, output="image")  # type: ignore
         # deactivate timer for components
-        for comp in self.pipe.pipe_component_list:
+        for comp in self.pipe.pipe_component_list:  # type: ignore
             comp.timer_on = False
         df_pr = MapData(df_pr, maybe_remove_image)
         df_list = CacheData(df_pr).get_cache()
@@ -184,12 +183,11 @@ class Evaluator:  # pylint: disable=R0903
     def _clean_up_predict_dataflow_annotations(self, df_pr: DataFlow) -> DataFlow:
         # will use the first pipe component of MultiThreadPipelineComponent to get meta annotation
         pipe_or_component = self.pipe_component.pipe_components[0] if self.pipe_component is not None else self.pipe
-        assert pipe_or_component
-        meta_anns = pipe_or_component.get_meta_annotation()
+        meta_anns = pipe_or_component.get_meta_annotation()  # type: ignore
         possible_cats_in_datapoint = self.dataset.dataflow.categories.get_categories(as_dict=False, filtered=True)
 
         # clean-up procedure depends on the dataset type
-        if self.dataset.dataset_info.type == names.DS.TYPE.OBJ:
+        if self.dataset.dataset_info.type == DatasetType.object_detection:
             # we keep all image annotations that will not be generated through processing
             anns_to_keep = {ann for ann in possible_cats_in_datapoint if ann not in meta_anns["image_annotations"]}
             sub_cats_to_remove = meta_anns["sub_categories"]
@@ -205,11 +203,11 @@ class Evaluator:  # pylint: disable=R0903
                 remove_cats(sub_categories=sub_cats_to_remove, relationships=relationships_to_remove),
             )
 
-        elif self.dataset.dataset_info.type == names.DS.TYPE.SEQ:
+        elif self.dataset.dataset_info.type == DatasetType.sequence_classification:
             summary_sub_cats_to_remove = meta_anns["summaries"]
             df_pr = MapData(df_pr, remove_cats(summary_sub_categories=summary_sub_cats_to_remove))
 
-        elif self.dataset.dataset_info.type == names.DS.TYPE.TOK:
+        elif self.dataset.dataset_info.type == DatasetType.token_classification:
             sub_cats_to_remove = meta_anns["sub_categories"]
             df_pr = MapData(df_pr, remove_cats(sub_categories=sub_cats_to_remove))
         else:
