@@ -22,9 +22,10 @@ Abstract classes for unifying external base- and Doctection predictors
 
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any, List, Mapping, Optional, Tuple, Union
 
 from ..utils.detection_types import ImageType, Requirement
+from ..utils.settings import DefaultType, ObjectTypes, TypeOrStr, get_type
 
 
 class PredictorBase(ABC):
@@ -91,8 +92,8 @@ class DetectionResult:
     score: Optional[float] = None
     mask: Optional[List[float]] = None
     absolute_coords: bool = True
-    class_name: str = ""
-    text: Optional[str] = None
+    class_name: ObjectTypes = DefaultType.default_type
+    text: Optional[Union[str, ObjectTypes]] = None
     block: Optional[str] = None
     line: Optional[str] = None
     uuid: Optional[str] = None
@@ -112,6 +113,18 @@ class ObjectDetector(PredictorBase):
     and implement the :meth:`predict`.
     """
 
+    _categories: Mapping[str, ObjectTypes]
+
+    @property
+    def categories(self) -> Mapping[str, ObjectTypes]:
+        """categories"""
+        return self._categories
+
+    @categories.setter
+    def categories(self, categories: Mapping[str, TypeOrStr]) -> None:
+        """categories setter"""
+        self._categories = {key: get_type(value) for key, value in categories.items()}
+
     @abstractmethod
     def predict(self, np_img: ImageType) -> List[DetectionResult]:
         """
@@ -126,13 +139,12 @@ class ObjectDetector(PredictorBase):
         """
         return False
 
-    @abstractmethod
-    def possible_categories(self) -> List[str]:
+    def possible_categories(self) -> List[ObjectTypes]:
         """
         Abstract method possible_categories. Must implement a method that returns a list of possible detectable
         categories
         """
-        raise NotImplementedError
+        return list(self.categories.values())
 
 
 class PdfMiner(PredictorBase):
@@ -141,10 +153,18 @@ class PdfMiner(PredictorBase):
     Use this to connect external pdf miners and wrap them into Deep-Doctection predictors.
     """
 
-    def __init__(self) -> None:
-        super().__init__()
-        self._pdf_bytes: Optional[bytes] = None
-        self._page: Any = None
+    _categories: Mapping[str, ObjectTypes]
+    _pdf_bytes: Optional[bytes] = None
+    _page: Any = None
+
+    @property
+    def categories(self) -> Mapping[str, ObjectTypes]:
+        """categories"""
+        return self._categories
+
+    @categories.setter
+    def categories(self, categories: Mapping[str, TypeOrStr]) -> None:
+        self._categories = {key: get_type(value) for key, value in categories.items()}
 
     @abstractmethod
     def predict(self, pdf_bytes: bytes) -> List[DetectionResult]:
@@ -170,13 +190,11 @@ class PdfMiner(PredictorBase):
         """
         return False
 
-    @abstractmethod
-    def possible_categories(self) -> List[str]:
+    def possible_categories(self) -> List[ObjectTypes]:
         """
-        Abstract method possible_categories. Must implement a method that returns a list of possible detectable
-        categories
+        Returns a list of possible detectable categories
         """
-        raise NotImplementedError
+        return list(self.categories.values())
 
 
 class TextRecognizer(PredictorBase):
@@ -227,9 +245,9 @@ class TokenClassResult:
     token_id: int
     token: str
     class_id: int
-    class_name: str = ""
-    semantic_name: str = ""
-    bio_tag: str = ""
+    class_name: ObjectTypes = DefaultType.default_type
+    semantic_name: ObjectTypes = DefaultType.default_type
+    bio_tag: ObjectTypes = DefaultType.default_type
     score: Optional[float] = None
 
 
@@ -244,7 +262,7 @@ class SequenceClassResult:
     """
 
     class_id: int
-    class_name: str = ""
+    class_name: ObjectTypes = DefaultType.default_type
     score: Optional[float] = None
 
 
@@ -254,6 +272,18 @@ class LMTokenClassifier(PredictorBase):
     predictors wrap them into a class derived from this class. Note, that this class is still DL library agnostic.
     """
 
+    _categories: Mapping[str, ObjectTypes]
+
+    @property
+    def categories(self) -> Mapping[str, ObjectTypes]:
+        """categories"""
+        return self._categories
+
+    @categories.setter
+    def categories(self, categories: Mapping[str, TypeOrStr]) -> None:
+        """categories setter"""
+        self._categories = {key: get_type(value) for key, value in categories.items()}
+
     @abstractmethod
     def predict(self, **encodings: Union[List[List[str]], "torch.Tensor"]) -> List[TokenClassResult]:  # type: ignore
         """
@@ -261,13 +291,11 @@ class LMTokenClassifier(PredictorBase):
         """
         raise NotImplementedError
 
-    @abstractmethod
-    def possible_tokens(self) -> List[str]:
+    def possible_tokens(self) -> List[ObjectTypes]:
         """
-        Abstract method possible_tokens. Must implement a method that returns a list of possible detectable
-        tokens
+        Returns a list of possible detectable tokens
         """
-        raise NotImplementedError
+        return list(self.categories.values())
 
     @abstractmethod
     def clone(self) -> "LMTokenClassifier":
@@ -283,6 +311,18 @@ class LMSequenceClassifier(PredictorBase):
     Deepdoctection predictors, wrap them into a class derived from this class.
     """
 
+    _categories: Mapping[str, ObjectTypes]
+
+    @property
+    def categories(self) -> Mapping[str, ObjectTypes]:
+        """categories"""
+        return self._categories
+
+    @categories.setter
+    def categories(self, categories: Mapping[str, TypeOrStr]) -> None:
+        """categories setter"""
+        self._categories = {key: get_type(value) for key, value in categories.items()}
+
     @abstractmethod
     def predict(self, **encodings: Union[List[List[str]], "torch.Tensor"]) -> SequenceClassResult:  # type: ignore
         """
@@ -290,13 +330,11 @@ class LMSequenceClassifier(PredictorBase):
         """
         raise NotImplementedError
 
-    @abstractmethod
-    def possible_categories(self) -> List[str]:
+    def possible_categories(self) -> List[ObjectTypes]:
         """
-        Abstract method possible_categories. Must implement a method that returns a list of possible detectable
-        categories for a sequence
+        Returns a list of possible detectable categories for a sequence
         """
-        raise NotImplementedError
+        return list(self.categories.values())
 
     @abstractmethod
     def clone(self) -> "LMSequenceClassifier":
@@ -312,6 +350,18 @@ class LanguageDetector(PredictorBase):
     ISO-639 code for the detected language.
     """
 
+    _categories: Mapping[str, ObjectTypes]
+
+    @property
+    def categories(self) -> Mapping[str, ObjectTypes]:
+        """categories"""
+        return self._categories
+
+    @categories.setter
+    def categories(self, categories: Mapping[str, TypeOrStr]) -> None:
+        """categories setter"""
+        self._categories = {key: get_type(value) for key, value in categories.items()}
+
     @abstractmethod
     def predict(self, text_string: str) -> DetectionResult:
         """
@@ -319,10 +369,8 @@ class LanguageDetector(PredictorBase):
         """
         raise NotImplementedError
 
-    @abstractmethod
-    def possible_languages(self) -> List[str]:
+    def possible_languages(self) -> List[ObjectTypes]:
         """
-        Abstract method possible_languages. Must implement a method that returns a list of possible detectable
-        languages
+        Returns a list of possible detectable languages
         """
-        raise NotImplementedError
+        return list(self.categories.values())
