@@ -20,7 +20,7 @@ D2 Faster Frcnn model as predictor for deepdoctection pipeline
 """
 
 from copy import copy
-from typing import Dict, List, Literal, Optional
+from typing import Dict, List, Literal, Mapping, Optional
 
 from ..utils.detection_types import ImageType, Requirement
 from ..utils.file_utils import (
@@ -29,8 +29,9 @@ from ..utils.file_utils import (
     get_pytorch_requirement,
     pytorch_available,
 )
+from ..utils.settings import ObjectTypes, TypeOrStr, get_type
+from ..utils.transform import InferenceResize
 from .base import DetectionResult, ObjectDetector, PredictorBase
-from .common import InferenceResize
 from .pt.ptutils import set_torch_auto_device
 
 if pytorch_available():
@@ -129,7 +130,7 @@ class D2FrcnnDetector(ObjectDetector):
         self,
         path_yaml: str,
         path_weights: str,
-        categories: Dict[str, str],
+        categories: Mapping[str, TypeOrStr],
         config_overwrite: Optional[List[str]] = None,
         device: Optional[Literal["cpu", "cuda"]] = None,
     ):
@@ -145,7 +146,7 @@ class D2FrcnnDetector(ObjectDetector):
         :param categories: A dict with key (indices) and values (category names). Index 0 must be reserved for a
                            dummy 'BG' category. Note, that this convention is different from the builtin D2 framework,
                            where models in the model zoo are trained with 'BG' class having the highest index.
-        :param config_overwrite:  Overwrite some hyper parameters defined by the yaml file with some new values. E.g.
+        :param config_overwrite:  Overwrite some hyperparameters defined by the yaml file with some new values. E.g.
                                  ["OUTPUT.FRCNN_NMS_THRESH=0.3","OUTPUT.RESULT_SCORE_THRESH=0.6"].
         :param device: "cpu" or "cuda". If not specified will auto select depending on what is available
         """
@@ -160,7 +161,7 @@ class D2FrcnnDetector(ObjectDetector):
             d2_conf_list.extend([key, val])
 
         self.path_yaml = path_yaml
-        self.categories = copy(categories)
+        self.categories = copy(categories)  # type: ignore
         self.config_overwrite = config_overwrite
         if device is not None:
             self.device = device
@@ -223,8 +224,8 @@ class D2FrcnnDetector(ObjectDetector):
         """
         for result in detection_results:
             result.class_name = self._categories_d2[str(result.class_id)]
-            assert isinstance(result.class_id, int)
-            result.class_id += 1
+            if isinstance(result.class_id, int):
+                result.class_id += 1
         return detection_results
 
     @classmethod
@@ -232,11 +233,11 @@ class D2FrcnnDetector(ObjectDetector):
         return [get_pytorch_requirement(), get_detectron2_requirement()]
 
     @classmethod
-    def _map_to_d2_categories(cls, categories: Dict[str, str]) -> Dict[str, str]:
-        return {str(int(k) - 1): v for k, v in categories.items()}
+    def _map_to_d2_categories(cls, categories: Mapping[str, TypeOrStr]) -> Dict[str, ObjectTypes]:
+        return {str(int(k) - 1): get_type(v) for k, v in categories.items()}
 
     def clone(self) -> PredictorBase:
         return self.__class__(self.path_yaml, self.path_weights, self.categories, self.config_overwrite, self.device)
 
-    def possible_categories(self) -> List[str]:
+    def possible_categories(self) -> List[ObjectTypes]:
         return list(self.categories.values())
