@@ -29,8 +29,16 @@ from ..utils.file_utils import (
     pytorch_available,
     transformers_available,
 )
-from ..utils.settings import names
-from .base import LMSequenceClassifier, LMTokenClassifier, PredictorBase, SequenceClassResult, TokenClassResult
+from ..utils.settings import (
+    BioTag,
+    ObjectTypes,
+    TokenClasses,
+    TypeOrStr,
+    get_type,
+    token_class_tag_to_token_class_with_tag,
+    token_class_with_tag_to_token_class_and_tag,
+)
+from .base import LMSequenceClassifier, LMTokenClassifier, SequenceClassResult, TokenClassResult
 from .pt.ptutils import set_torch_auto_device
 
 if pytorch_available():
@@ -50,6 +58,7 @@ def predict_token_classes(
     boxes: "Tensor",
     tokens: List[str],
     model: "LayoutLMForTokenClassification",
+    images: Optional[List["Tensor"]] = None,
 ) -> List[TokenClassResult]:
     """
     :param uuids: A list of uuids that correspond to a word that induces the resulting token
@@ -59,9 +68,15 @@ def predict_token_classes(
     :param boxes: Torch tensor of bounding boxes of type 'xyxy'
     :param tokens: List of original tokens taken from LayoutLMTokenizer
     :param model: layoutlm model for token classification
+    :param images: A list of torch image tensors or None
     :return: A list of TokenClassResults
     """
-    outputs = model(input_ids=input_ids, bbox=boxes, attention_mask=attention_mask, token_type_ids=token_type_ids)
+    if images is None:
+        outputs = model(input_ids=input_ids, bbox=boxes, attention_mask=attention_mask, token_type_ids=token_type_ids)
+    else:
+        outputs = model(
+            input_ids=input_ids, bbox=boxes, attention_mask=attention_mask, token_type_ids=token_type_ids, images=images
+        )
     score = torch.max(F.softmax(outputs.logits.squeeze(), dim=1), dim=1)
     token_class_predictions = outputs.logits.argmax(-1).squeeze().tolist()
     input_ids_list = input_ids.squeeze().tolist()
@@ -134,9 +149,9 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
         self,
         path_config_json: str,
         path_weights: str,
-        categories_semantics: Optional[Sequence[str]] = None,
-        categories_bio: Optional[Sequence[str]] = None,
-        categories: Optional[Mapping[str, str]] = None,
+        categories_semantics: Optional[Sequence[TypeOrStr]] = None,
+        categories_bio: Optional[Sequence[TypeOrStr]] = None,
+        categories: Optional[Mapping[str, TypeOrStr]] = None,
         device: Optional[Literal["cpu", "cuda"]] = None,
     ):
         """
@@ -149,19 +164,24 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
         """
 
         if categories is None:
-            assert categories_semantics is not None
-            assert categories_bio is not None
+            if categories_semantics is None:
+                raise ValueError("If categories is None then categories_semantics cannot be None")
+            if categories_bio is None:
+                raise ValueError("If categories is None then categories_bio cannot be None")
 
-        self.path_config_json = path_config_json
+        self.path_config = path_config_json
         self.path_weights = path_weights
-        self.categories_semantics = categories_semantics
-        self.categories_bio = categories_bio
+        self.categories_semantics = (
+            [get_type(cat_sem) for cat_sem in categories_semantics] if categories_semantics is not None else []
+        )
+        self.categories_bio = [get_type(cat_bio) for cat_bio in categories_bio] if categories_bio is not None else []
         if categories:
-            self.categories = copy(categories)
+            self.categories = copy(categories)  # type: ignore
         else:
-            self.categories = self._categories_orig_to_categories(categories_semantics, categories_bio)  # type: ignore
+            self.categories = self._categories_orig_to_categories(self.categories_semantics,  # type: ignore
+                                                                  self.categories_bio)  # type: ignore
 
-        config = PretrainedConfig.from_pretrained(pretrained_model_name_or_path=path_config_json)
+        config = PretrainedConfig.from_pretrained(pretrained_model_name_or_path=self.path_config)
         self.model = LayoutLMForTokenClassification.from_pretrained(
             pretrained_model_name_or_path=path_weights, config=config
         )
@@ -195,14 +215,14 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
         boxes = encodings.get("bbox")
         tokens = encodings.get("tokens")
 
-        assert isinstance(ann_ids, list)
+        assert isinstance(ann_ids, list), type(ann_ids)
         if len(ann_ids) > 1:
             raise ValueError("HFLayoutLmTokenClassifier accepts for inference only batch size of 1")
-        assert isinstance(input_ids, torch.Tensor)
-        assert isinstance(attention_mask, torch.Tensor)
-        assert isinstance(token_type_ids, torch.Tensor)
-        assert isinstance(boxes, torch.Tensor)
-        assert isinstance(tokens, list)
+        assert isinstance(input_ids, torch.Tensor), type(input_ids)
+        assert isinstance(attention_mask, torch.Tensor), type(attention_mask)
+        assert isinstance(token_type_ids, torch.Tensor), type(token_type_ids)
+        assert isinstance(boxes, torch.Tensor), type(boxes)
+        assert isinstance(tokens, list), type(tokens)
 
         input_ids = input_ids.to(self.device)
         attention_mask = attention_mask.to(self.device)
@@ -210,44 +230,42 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
         boxes = boxes.to(self.device)
 
         results = predict_token_classes(
-            ann_ids[0],
-            input_ids,
-            attention_mask,
-            token_type_ids,
-            boxes,
-            tokens[0],
-            self.model,
+            ann_ids[0], input_ids, attention_mask, token_type_ids, boxes, tokens[0], self.model, None
         )
 
         return self._map_category_names(results)
 
     @staticmethod
-    def _categories_orig_to_categories(categories_semantics: List[str], categories_bio: List[str]) -> Dict[str, str]:
-        categories_list = [
-            x + "-" + y for x in categories_bio if x != names.NER.O for y in categories_semantics if y != names.C.O
-        ] + [names.NER.O]
+    def _categories_orig_to_categories(
+        categories_semantics: List[TokenClasses], categories_bio: List[BioTag]
+    ) -> Dict[str, ObjectTypes]:
+        categories_list = sorted(
+            {
+                token_class_tag_to_token_class_with_tag(token, tag)
+                for token in categories_semantics
+                for tag in categories_bio
+            }
+        )
         return {str(k): v for k, v in enumerate(categories_list, 1)}
 
     def _map_category_names(self, token_results: List[TokenClassResult]) -> List[TokenClassResult]:
         for result in token_results:
             result.class_name = self.categories[str(result.class_id + 1)]
-            result.semantic_name = result.class_name.split("-")[1] if "-" in result.class_name else names.C.O
-            result.bio_tag = result.class_name.split("-")[0] if "-" in result.class_name else names.NER.O
+            token_class, tag = token_class_with_tag_to_token_class_and_tag(result.class_name)
+            result.semantic_name = token_class
+            result.bio_tag = tag
             result.class_id += 1
         return token_results
 
     def clone(self) -> "HFLayoutLmTokenClassifier":
         return self.__class__(
-            self.path_config_json,
+            self.path_config,
             self.path_weights,
             self.categories_semantics,
             self.categories_bio,
             self.categories,
         )
 
-    def possible_tokens(self) -> List[str]:
-        return list(self.categories.values())
-
 
 class HFLayoutLmSequenceClassifier(LMSequenceClassifier):
     """
@@ -286,12 +304,12 @@ class HFLayoutLmSequenceClassifier(LMSequenceClassifier):
         self,
         path_config_json: str,
         path_weights: str,
-        categories: Dict[str, str],
+        categories: Mapping[str, TypeOrStr],
         device: Optional[Literal["cpu", "cuda"]] = None,
     ):
         self.path_config = path_config_json
         self.path_weights = path_weights
-        self.categories = copy(categories)
+        self.categories = copy(categories)  # type: ignore
         config = PretrainedConfig.from_pretrained(pretrained_model_name_or_path=path_config_json)
         self.model = LayoutLMForSequenceClassification.from_pretrained(
             pretrained_model_name_or_path=path_weights, config=config
@@ -309,10 +327,10 @@ class HFLayoutLmSequenceClassifier(LMSequenceClassifier):
         token_type_ids = encodings.get("token_type_ids")
         boxes = encodings.get("bbox")
 
-        assert isinstance(input_ids, torch.Tensor)
-        assert isinstance(attention_mask, torch.Tensor)
-        assert isinstance(token_type_ids, torch.Tensor)
-        assert isinstance(boxes, torch.Tensor)
+        assert isinstance(input_ids, torch.Tensor), type(input_ids)
+        assert isinstance(attention_mask, torch.Tensor), type(attention_mask)
+        assert isinstance(token_type_ids, torch.Tensor), type(token_type_ids)
+        assert isinstance(boxes, torch.Tensor), type(boxes)
 
         input_ids = input_ids.to(self.device)
         attention_mask = attention_mask.to(self.device)
@@ -337,6 +355,3 @@ class HFLayoutLmSequenceClassifier(LMSequenceClassifier):
 
     def clone(self) -> "HFLayoutLmSequenceClassifier":
         return self.__class__(self.path_config, self.path_weights, self.categories)
-
-    def possible_categories(self) -> List[str]:
-        return list(self.categories.values())
