@@ -30,7 +30,7 @@ from termcolor import colored
 
 from ..utils.fs import download
 from ..utils.logger import logger
-from ..utils.settings import names
+from ..utils.settings import Languages, LayoutType, ObjectTypes
 from ..utils.systools import get_configs_dir_path, get_weights_dir_path
 
 __all__ = ["ModelCatalog", "ModelDownloadManager", "print_model_infos", "ModelProfile"]
@@ -52,7 +52,7 @@ class ModelProfile:
     hf_model_name: Optional[str] = field(default=None)
     hf_config_file: Optional[List[str]] = field(default=None)
     urls: Optional[List[str]] = field(default=None)
-    categories: Optional[Dict[str, str]] = field(default=None)
+    categories: Optional[Dict[str, ObjectTypes]] = field(default=None)
 
     def as_dict(self) -> Dict[str, Any]:
         """
@@ -104,7 +104,13 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/tp_casc_rcnn_X_32xd4_50_FPN_GN_2FC_publaynet_inference_only",
             hf_model_name="model-800000_inf_only",
             hf_config_file=["conf_frcnn_layout.yaml"],
-            categories={"1": names.C.TEXT, "2": names.C.TITLE, "3": names.C.LIST, "4": names.C.TAB, "5": names.C.FIG},
+            categories={
+                "1": LayoutType.text,
+                "2": LayoutType.title,
+                "3": LayoutType.list,
+                "4": LayoutType.table,
+                "5": LayoutType.figure,
+            },
         ),
         "cell/model-1800000_inf_only.data-00000-of-00001": ModelProfile(
             name="cell/model-1800000_inf_only.data-00000-of-00001",
@@ -115,7 +121,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/tp_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_c_inference_only",
             hf_model_name="model-1800000_inf_only",
             hf_config_file=["conf_frcnn_cell.yaml"],
-            categories={"1": names.C.CELL},
+            categories={"1": LayoutType.cell},
         ),
         "item/model-1620000_inf_only.data-00000-of-00001": ModelProfile(
             name="item/model-1620000_inf_only.data-00000-of-00001",
@@ -126,7 +132,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/tp_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_rc_inference_only",
             hf_model_name="model-1620000_inf_only",
             hf_config_file=["conf_frcnn_rows.yaml"],
-            categories={"1": names.C.ROW, "2": names.C.COL},
+            categories={"1": LayoutType.row, "2": LayoutType.column},
         ),
         "item/model-1620000.data-00000-of-00001": ModelProfile(
             name="item/model-1620000.data-00000-of-00001",
@@ -137,7 +143,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/tp_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_rc",
             hf_model_name="model-1620000",
             hf_config_file=["conf_frcnn_rows.yaml"],
-            categories={"1": names.C.ROW, "2": names.C.COL},
+            categories={"1": LayoutType.row, "2": LayoutType.column},
         ),
         "layout/model-800000.data-00000-of-00001": ModelProfile(
             name="layout/model-800000.data-00000-of-00001",
@@ -148,7 +154,13 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/tp_casc_rcnn_X_32xd4_50_FPN_GN_2FC_publaynet",
             hf_model_name="model-800000",
             hf_config_file=["conf_frcnn_layout.yaml"],
-            categories={"1": names.C.TEXT, "2": names.C.TITLE, "3": names.C.LIST, "4": names.C.TAB, "5": names.C.FIG},
+            categories={
+                "1": LayoutType.text,
+                "2": LayoutType.title,
+                "3": LayoutType.list,
+                "4": LayoutType.table,
+                "5": LayoutType.figure,
+            },
         ),
         "cell/model-1800000.data-00000-of-00001": ModelProfile(
             name="cell/model-1800000.data-00000-of-00001",
@@ -159,7 +171,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/tp_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_c",
             hf_model_name="model-1800000",
             hf_config_file=["conf_frcnn_cell.yaml"],
-            categories={"1": names.C.CELL},
+            categories={"1": LayoutType.cell},
         ),
         "layout/d2_model-800000-layout.pkl": ModelProfile(
             name="layout/d2_model-800000-layout.pkl",
@@ -170,7 +182,13 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_publaynet_inference_only",
             hf_model_name="d2_model-800000-layout.pkl",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.TEXT, "2": names.C.TITLE, "3": names.C.LIST, "4": names.C.TAB, "5": names.C.FIG},
+            categories={
+                "1": LayoutType.text,
+                "2": LayoutType.title,
+                "3": LayoutType.list,
+                "4": LayoutType.table,
+                "5": LayoutType.figure,
+            },
         ),
         "layout/d2_model_0829999_layout_inf_only.pt": ModelProfile(
             name="layout/d2_model_0829999_layout_inf_only.pt",
@@ -181,7 +199,13 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_publaynet_inference_only",
             hf_model_name="d2_model_0829999_layout_inf_only.pt",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.TEXT, "2": names.C.TITLE, "3": names.C.LIST, "4": names.C.TAB, "5": names.C.FIG},
+            categories={
+                "1": LayoutType.text,
+                "2": LayoutType.title,
+                "3": LayoutType.list,
+                "4": LayoutType.table,
+                "5": LayoutType.figure,
+            },
         ),
         "layout/d2_model_0829999_layout.pth": ModelProfile(
             name="layout/d2_model_0829999_layout.pth",
@@ -192,7 +216,13 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_publaynet_inference_only",
             hf_model_name="d2_model_0829999_layout.pth",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.TEXT, "2": names.C.TITLE, "3": names.C.LIST, "4": names.C.TAB, "5": names.C.FIG},
+            categories={
+                "1": LayoutType.text,
+                "2": LayoutType.title,
+                "3": LayoutType.list,
+                "4": LayoutType.table,
+                "5": LayoutType.figure,
+            },
         ),
         "cell/d2_model-1800000-cell.pkl": ModelProfile(
             name="cell/d2_model-1800000-cell.pkl",
@@ -203,7 +233,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_c_inference_only",
             hf_model_name="d2_model-1800000-cell.pkl",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.CELL},
+            categories={"1": LayoutType.cell},
         ),
         "cell/d2_model_1849999_cell_inf_only.pt": ModelProfile(
             name="cell/d2_model_1849999_cell_inf_only.pt",
@@ -214,7 +244,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_c_inference_only",
             hf_model_name="d2_model_1849999_cell_inf_only.pt",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.CELL},
+            categories={"1": LayoutType.cell},
         ),
         "cell/d2_model_1849999_cell.pth": ModelProfile(
             name="cell/d2_model_1849999_cell.pth",
@@ -225,7 +255,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_c_inference_only",
             hf_model_name="cell/d2_model_1849999_cell.pth",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.CELL},
+            categories={"1": LayoutType.cell},
         ),
         "item/d2_model-1620000-item.pkl": ModelProfile(
             name="item/d2_model-1620000-item.pkl",
@@ -236,7 +266,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_rc_inference_only",
             hf_model_name="d2_model-1620000-item.pkl",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.ROW, "2": names.C.COL},
+            categories={"1": LayoutType.row, "2": LayoutType.column},
         ),
         "item/d2_model_1639999_item.pth": ModelProfile(
             name="item/d2_model_1639999_item.pth",
@@ -247,7 +277,7 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_rc_inference_only",
             hf_model_name="d2_model_1639999_item.pth",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.ROW, "2": names.C.COL},
+            categories={"1": LayoutType.row, "2": LayoutType.column},
         ),
         "item/d2_model_1639999_item_inf_only.pt": ModelProfile(
             name="item/d2_model_1639999_item_inf_only.pt",
@@ -258,39 +288,15 @@ class ModelCatalog:
             hf_repo_id="deepdoctection/d2_casc_rcnn_X_32xd4_50_FPN_GN_2FC_pubtabnet_rc_inference_only",
             hf_model_name="d2_model_1639999_item_inf_only.pt",
             hf_config_file=["Base-RCNN-FPN.yaml", "CASCADE_RCNN_R_50_FPN_GN.yaml"],
-            categories={"1": names.C.ROW, "2": names.C.COL},
-        ),
-        "mrm8488/layoutlm-finetuned-funsd/pytorch_model.bin": ModelProfile(
-            name="mrm8488/layoutlm-finetuned-funsd/pytorch_model.bin",
-            description="LayoutLM pre-trained on CDIP and fine tuned on funsd",
-            config="mrm8488/layoutlm-finetuned-funsd/config.json",
-            size=[450639205],
-            tp_model=False,
-            hf_repo_id="mrm8488/layoutlm-finetuned-funsd",
-            hf_model_name="pytorch_model.bin",
-            hf_config_file=["config.json"],
-            categories={
-                "1": "B-ANSWER",
-                "2": "B-HEAD",
-                "3": "B-QUESTION",
-                "4": "E-ANSWER",
-                "5": "E-HEAD",
-                "6": "E-QUESTION",
-                "7": "I-ANSWER",
-                "8": "I-HEAD",
-                "9": "I-QUESTION",
-                "10": "O",
-                "11": "S-ANSWER",
-                "12": "S-HEAD",
-                "13": "S-QUESTION",
-            },
+            categories={"1": LayoutType.row, "2": LayoutType.column},
         ),
         "microsoft/layoutlm-base-uncased/pytorch_model.bin": ModelProfile(
             name="microsoft/layoutlm-base-uncased/pytorch_model.bin",
             description="LayoutLM is a simple but effective pre-training method of text and layout for document image"
             " understanding and information extraction tasks, such as form understanding and receipt"
             " understanding. LayoutLM archived the SOTA results on multiple datasets. This model does not"
-            "contain any head and has to be fine tuned on a downstream task.",
+            "contain any head and has to be fine tuned on a downstream task. This is model has been trained "
+            "on 11M documents for 2 epochs.  Configuration: 12-layer, 768-hidden, 12-heads, 113M parameters",
             size=[453093832],
             tp_model=False,
             config="microsoft/layoutlm-base-uncased/config.json",
@@ -298,188 +304,202 @@ class ModelCatalog:
             hf_model_name="pytorch_model.bin",
             hf_config_file=["config.json"],
         ),
+        "microsoft/layoutlm-large-uncased/pytorch_model.bin": ModelProfile(
+            name="microsoft/layoutlm-large-uncased/pytorch_model.bin",
+            description="LayoutLM is a simple but effective pre-training method of text and layout for document image"
+            " understanding and information extraction tasks, such as form understanding and receipt"
+            " understanding. LayoutLM archived the SOTA results on multiple datasets. This model does not"
+            "contain any head and has to be fine tuned on a downstream task. This is model has been trained"
+            " on 11M documents for 2 epochs.  Configuration: 24-layer, 1024-hidden, 16-heads, 343M parameters",
+            size=[1361845448],
+            tp_model=False,
+            config="microsoft/layoutlm-large-uncased/config.json",
+            hf_repo_id="microsoft/layoutlm-large-uncased",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json"],
+        ),
         "fasttext/lid.176.bin": ModelProfile(
             name="fasttext/lid.176.bin",
             description="Fasttext language detection model",
             size=[131266198],
             urls=["https://dl.fbaipublicfiles.com/fasttext/supervised-models/lid.176.bin"],
             categories={
-                "__label__en": names.NLP.LANG.ENG,
-                "__label__ru": names.NLP.LANG.RUS,
-                "__label__de": names.NLP.LANG.DEU,
-                "__label__fr": names.NLP.LANG.FRE,
-                "__label__it": names.NLP.LANG.ITA,
-                "__label__ja": names.NLP.LANG.JPN,
-                "__label__es": names.NLP.LANG.SPA,
-                "__label__ceb": names.NLP.LANG.CEB,
-                "__label__tr": names.NLP.LANG.TUR,
-                "__label__pt": names.NLP.LANG.POR,
-                "__label__uk": names.NLP.LANG.UKR,
-                "__label__eo": names.NLP.LANG.EPO,
-                "__label__pl": names.NLP.LANG.POL,
-                "__label__sv": names.NLP.LANG.SWE,
-                "__label__nl": names.NLP.LANG.DUT,
-                "__label__he": names.NLP.LANG.HEB,
-                "__label__zh": names.NLP.LANG.CHI,
-                "__label__hu": names.NLP.LANG.HUN,
-                "__label__ar": names.NLP.LANG.ARA,
-                "__label__ca": names.NLP.LANG.CAT,
-                "__label__fi": names.NLP.LANG.FIN,
-                "__label__cs": names.NLP.LANG.CZE,
-                "__label__fa": names.NLP.LANG.PER,
-                "__label__sr": names.NLP.LANG.SRP,
-                "__label__el": names.NLP.LANG.GRE,
-                "__label__vi": names.NLP.LANG.VIE,
-                "__label__bg": names.NLP.LANG.BUL,
-                "__label__ko": names.NLP.LANG.KOR,
-                "__label__no": names.NLP.LANG.NOR,
-                "__label__mk": names.NLP.LANG.MAC,
-                "__label__ro": names.NLP.LANG.RUM,
-                "__label__id": names.NLP.LANG.IND,
-                "__label__th": names.NLP.LANG.THA,
-                "__label__hy": names.NLP.LANG.ARM,
-                "__label__da": names.NLP.LANG.DAN,
-                "__label__ta": names.NLP.LANG.TAM,
-                "__label__hi": names.NLP.LANG.HIN,
-                "__label__hr": names.NLP.LANG.HRV,
-                "__label__sh": "",
-                "__label__be": names.NLP.LANG.BEL,
-                "__label__ka": names.NLP.LANG.GEO,
-                "__label__te": names.NLP.LANG.TEL,
-                "__label__kk": names.NLP.LANG.KAZ,
-                "__label__war": names.NLP.LANG.WAR,
-                "__label__lt": names.NLP.LANG.LIT,
-                "__label__gl": names.NLP.LANG.GLG,
-                "__label__sk": names.NLP.LANG.SLO,
-                "__label__bn": names.NLP.LANG.BEN,
-                "__label__eu": names.NLP.LANG.BAQ,
-                "__label__sl": names.NLP.LANG.SLV,
-                "__label__kn": "",
-                "__label__ml": names.NLP.LANG.MAL,
-                "__label__mr": names.NLP.LANG.MAR,
-                "__label__et": names.NLP.LANG.EST,
-                "__label__az": names.NLP.LANG.AZE,
-                "__label__ms": "",
-                "__label__sq": names.NLP.LANG.ALB,
-                "__label__la": names.NLP.LANG.LAT,
-                "__label__bs": names.NLP.LANG.BOS,
-                "__label__nn": names.NLP.LANG.NNO,
-                "__label__ur": names.NLP.LANG.URD,
-                "__label__lv": "",
-                "__label__my": "",
-                "__label__tt": "",
-                "__label__af": "",
-                "__label__oc": "",
-                "__label__nds": "",
-                "__label__ky": "",
-                "__label__ast": "",
-                "__label__tl": "",
-                "__label__is": "",
-                "__label__ia": "",
-                "__label__si": "",
-                "__label__gu": "",
-                "__label__km": "",
-                "__label__br": "",
-                "__label__ba": "",
-                "__label__uz": "",
-                "__label__bo": "",
-                "__label__pa": "",
-                "__label__vo": "",
-                "__label__als": "",
-                "__label__ne": "",
-                "__label__cy": "",
-                "__label__jbo": "",
-                "__label__fy": "",
-                "__label__mn": "",
-                "__label__lb": "",
-                "__label__ce": "",
-                "__label__ug": "",
-                "__label__tg": "",
-                "__label__sco": "",
-                "__label__sa": "",
-                "__label__cv": "",
-                "__label__jv": "",
-                "__label__min": "",
-                "__label__io": "",
-                "__label__or": "",
-                "__label__as": "",
-                "__label__new": "",
-                "__label__ga": "",
-                "__label__mg": "",
-                "__label__an": "",
-                "__label__ckb": "",
-                "__label__sw": "",
-                "__label__bar": "",
-                "__label__lmo": "",
-                "__label__yi": ":" "",
-                "__label__arz": "",
-                "__label__mhr": "",
-                "__label__azb": "",
-                "__label__sah": "",
-                "__label__pnb": "",
-                "__label__su": "",
-                "__label__bpy": "",
-                "__label__pms": "",
-                "__label__ilo": "",
-                "__label__wuu": "",
-                "__label__ku": "",
-                "__label__ps": "",
-                "__label__ie": "",
-                "__label__xmf": "",
-                "__label__yue": "",
-                "__label__gom": "",
-                "__label__li": "",
-                "__label__mwl": "",
-                "__label__kw": "",
-                "__label__sd": "",
-                "__label__hsb": "",
-                "__label__scn": "",
-                "__label__gd": "",
-                "__label__pam": "",
-                "__label__bh": "",
-                "__label__mai": "",
-                "__label__vec": "",
-                "__label__mt": "",
-                "__label__dv": "",
-                "__label__wa": "",
-                "__label__mzn": "",
-                "__label__am": "",
-                "__label__qu": "",
-                "__label__eml": "",
-                "__label__cbk": "",
-                "__label__tk": "",
-                "__label__rm": "",
-                "__label__os": "",
-                "__label__vls": "",
-                "__label__yo": "",
-                "__label__lo": "",
-                "__label__lez": "",
-                "__label__so": "",
-                "__label__myv": "",
-                "__label__diq": "",
-                "__label__mrj": "",
-                "__label__dsb": "",
-                "__label__frr": "",
-                "__label__ht": "",
-                "__label__gn": "",
-                "__label__bxr": "",
-                "__label__kv": "",
-                "__label__sc": "",
-                "__label__nah": "",
-                "__label__krc": "",
-                "__label__bcl": "",
-                "__label__nap": "",
-                "__label__gv": "",
-                "__label__av": "",
-                "__label__rue": "",
-                "__label__xal": "",
-                "__label__pfl": "",
-                "__label__dty": "",
-                "__label__hif": "",
-                "__label__co": "",
-                "__label__lrc": "",
-                "__label__vep": "",
-                "__label__tyv": "",
+                "__label__en": Languages.english,
+                "__label__ru": Languages.russian,
+                "__label__de": Languages.german,
+                "__label__fr": Languages.french,
+                "__label__it": Languages.italian,
+                "__label__ja": Languages.japanese,
+                "__label__es": Languages.spanish,
+                "__label__ceb": Languages.cebuano,
+                "__label__tr": Languages.turkish,
+                "__label__pt": Languages.portuguese,
+                "__label__uk": Languages.ukrainian,
+                "__label__eo": Languages.esperanto,
+                "__label__pl": Languages.polish,
+                "__label__sv": Languages.swedish,
+                "__label__nl": Languages.dutch,
+                "__label__he": Languages.hebrew,
+                "__label__zh": Languages.chinese,
+                "__label__hu": Languages.hungarian,
+                "__label__ar": Languages.arabic,
+                "__label__ca": Languages.catalan,
+                "__label__fi": Languages.finnish,
+                "__label__cs": Languages.czech,
+                "__label__fa": Languages.persian,
+                "__label__sr": Languages.serbian,
+                "__label__el": Languages.greek,
+                "__label__vi": Languages.vietnamese,
+                "__label__bg": Languages.bulgarian,
+                "__label__ko": Languages.korean,
+                "__label__no": Languages.norwegian,
+                "__label__mk": Languages.macedonian,
+                "__label__ro": Languages.romanian,
+                "__label__id": Languages.indonesian,
+                "__label__th": Languages.thai,
+                "__label__hy": Languages.armenian,
+                "__label__da": Languages.danish,
+                "__label__ta": Languages.tamil,
+                "__label__hi": Languages.hindi,
+                "__label__hr": Languages.croatian,
+                "__label__sh": Languages.not_defined,
+                "__label__be": Languages.belarusian,
+                "__label__ka": Languages.georgian,
+                "__label__te": Languages.telugu,
+                "__label__kk": Languages.kazakh,
+                "__label__war": Languages.waray,
+                "__label__lt": Languages.lithuanian,
+                "__label__gl": Languages.scottish,
+                "__label__sk": Languages.slovak,
+                "__label__bn": Languages.benin,
+                "__label__eu": Languages.basque,
+                "__label__sl": Languages.slovenian,
+                "__label__kn": Languages.not_defined,
+                "__label__ml": Languages.malayalam,
+                "__label__mr": Languages.marathi,
+                "__label__et": Languages.estonian,
+                "__label__az": Languages.azerbaijani,
+                "__label__ms": Languages.not_defined,
+                "__label__sq": Languages.albanian,
+                "__label__la": Languages.latin,
+                "__label__bs": Languages.bosnian,
+                "__label__nn": Languages.norwegian_nynorsk,
+                "__label__ur": Languages.urdu,
+                "__label__lv": Languages.not_defined,
+                "__label__my": Languages.not_defined,
+                "__label__tt": Languages.not_defined,
+                "__label__af": Languages.not_defined,
+                "__label__oc": Languages.not_defined,
+                "__label__nds": Languages.not_defined,
+                "__label__ky": Languages.not_defined,
+                "__label__ast": Languages.not_defined,
+                "__label__tl": Languages.not_defined,
+                "__label__is": Languages.not_defined,
+                "__label__ia": Languages.not_defined,
+                "__label__si": Languages.not_defined,
+                "__label__gu": Languages.not_defined,
+                "__label__km": Languages.not_defined,
+                "__label__br": Languages.not_defined,
+                "__label__ba": Languages.not_defined,
+                "__label__uz": Languages.not_defined,
+                "__label__bo": Languages.not_defined,
+                "__label__pa": Languages.not_defined,
+                "__label__vo": Languages.not_defined,
+                "__label__als": Languages.not_defined,
+                "__label__ne": Languages.not_defined,
+                "__label__cy": Languages.not_defined,
+                "__label__jbo": Languages.not_defined,
+                "__label__fy": Languages.not_defined,
+                "__label__mn": Languages.not_defined,
+                "__label__lb": Languages.not_defined,
+                "__label__ce": Languages.not_defined,
+                "__label__ug": Languages.not_defined,
+                "__label__tg": Languages.not_defined,
+                "__label__sco": Languages.not_defined,
+                "__label__sa": Languages.not_defined,
+                "__label__cv": Languages.not_defined,
+                "__label__jv": Languages.not_defined,
+                "__label__min": Languages.not_defined,
+                "__label__io": Languages.not_defined,
+                "__label__or": Languages.not_defined,
+                "__label__as": Languages.not_defined,
+                "__label__new": Languages.not_defined,
+                "__label__ga": Languages.not_defined,
+                "__label__mg": Languages.not_defined,
+                "__label__an": Languages.not_defined,
+                "__label__ckb": Languages.not_defined,
+                "__label__sw": Languages.not_defined,
+                "__label__bar": Languages.not_defined,
+                "__label__lmo": Languages.not_defined,
+                "__label__yi": Languages.not_defined,
+                "__label__arz": Languages.not_defined,
+                "__label__mhr": Languages.not_defined,
+                "__label__azb": Languages.not_defined,
+                "__label__sah": Languages.not_defined,
+                "__label__pnb": Languages.not_defined,
+                "__label__su": Languages.not_defined,
+                "__label__bpy": Languages.not_defined,
+                "__label__pms": Languages.not_defined,
+                "__label__ilo": Languages.not_defined,
+                "__label__wuu": Languages.not_defined,
+                "__label__ku": Languages.not_defined,
+                "__label__ps": Languages.not_defined,
+                "__label__ie": Languages.not_defined,
+                "__label__xmf": Languages.not_defined,
+                "__label__yue": Languages.not_defined,
+                "__label__gom": Languages.not_defined,
+                "__label__li": Languages.not_defined,
+                "__label__mwl": Languages.not_defined,
+                "__label__kw": Languages.not_defined,
+                "__label__sd": Languages.not_defined,
+                "__label__hsb": Languages.not_defined,
+                "__label__scn": Languages.not_defined,
+                "__label__gd": Languages.not_defined,
+                "__label__pam": Languages.not_defined,
+                "__label__bh": Languages.not_defined,
+                "__label__mai": Languages.not_defined,
+                "__label__vec": Languages.not_defined,
+                "__label__mt": Languages.not_defined,
+                "__label__dv": Languages.not_defined,
+                "__label__wa": Languages.not_defined,
+                "__label__mzn": Languages.not_defined,
+                "__label__am": Languages.not_defined,
+                "__label__qu": Languages.not_defined,
+                "__label__eml": Languages.not_defined,
+                "__label__cbk": Languages.not_defined,
+                "__label__tk": Languages.not_defined,
+                "__label__rm": Languages.not_defined,
+                "__label__os": Languages.not_defined,
+                "__label__vls": Languages.not_defined,
+                "__label__yo": Languages.not_defined,
+                "__label__lo": Languages.not_defined,
+                "__label__lez": Languages.not_defined,
+                "__label__so": Languages.not_defined,
+                "__label__myv": Languages.not_defined,
+                "__label__diq": Languages.not_defined,
+                "__label__mrj": Languages.not_defined,
+                "__label__dsb": Languages.not_defined,
+                "__label__frr": Languages.not_defined,
+                "__label__ht": Languages.not_defined,
+                "__label__gn": Languages.not_defined,
+                "__label__bxr": Languages.not_defined,
+                "__label__kv": Languages.not_defined,
+                "__label__sc": Languages.not_defined,
+                "__label__nah": Languages.not_defined,
+                "__label__krc": Languages.not_defined,
+                "__label__bcl": Languages.not_defined,
+                "__label__nap": Languages.not_defined,
+                "__label__gv": Languages.not_defined,
+                "__label__av": Languages.not_defined,
+                "__label__rue": Languages.not_defined,
+                "__label__xal": Languages.not_defined,
+                "__label__pfl": Languages.not_defined,
+                "__label__dty": Languages.not_defined,
+                "__label__hif": Languages.not_defined,
+                "__label__co": Languages.not_defined,
+                "__label__lrc": Languages.not_defined,
+                "__label__vep": Languages.not_defined,
+                "__label__tyv": Languages.not_defined,
             },
         ),
     }
@@ -499,7 +519,7 @@ class ModelCatalog:
         if profile.name is not None:
             return os.path.join(get_weights_dir_path(), profile.name)
         logger.info(
-            "Model is not registered. Please make sure the weights are available in the weights cache " "directory"
+            "Model is not registered. Please make sure the weights are available in the weights cache directory"
         )
         return os.path.join(get_weights_dir_path(), name)
 
@@ -638,7 +658,8 @@ class ModelDownloadManager:
                 file_names = get_tp_weight_names(name)
             else:
                 hf_model_name = profile.hf_model_name
-                assert isinstance(hf_model_name, str)
+                if hf_model_name is None:
+                    raise ValueError("hf_model_name cannot be None")
                 file_names.append(hf_model_name)
             if profile.hf_repo_id:
                 ModelDownloadManager.load_model_from_hf_hub(profile, absolute_path_weights, file_names)
@@ -664,18 +685,23 @@ class ModelDownloadManager:
                            models
         """
         repo_id = profile.hf_repo_id
-        assert repo_id
+        if repo_id is None:
+            raise ValueError("hf_repo_id cannot be None")
         directory, _ = os.path.split(absolute_path)
 
         for expect_size, file_name in zip(profile.size, file_names):
             size = ModelDownloadManager._load_from_hf_hub(repo_id, file_name, directory)
             if expect_size is not None and size != expect_size:
-                logger.error("File downloaded from %s does not match the expected size!", repo_id)
-                logger.error("You may have downloaded a broken file, or the upstream may have modified the file.")
+                logger.error(
+                    "File downloaded from %s does not match the expected size! You may have downloaded"
+                    " a broken file, or the upstream may have modified the file.",
+                    repo_id,
+                )
 
     @staticmethod
     def _load_from_gd(profile: ModelProfile, absolute_path: str, file_names: List[str]) -> None:
-        assert profile.urls is not None
+        if profile.urls is None:
+            raise ValueError("urls cannot be None")
         for size, url, file_name in zip(profile.size, profile.urls, file_names):
             directory, _ = os.path.split(absolute_path)
             download(str(url), directory, file_name, int(size))
@@ -691,10 +717,11 @@ class ModelDownloadManager:
         """
 
         repo_id = profile.hf_repo_id
-        assert repo_id
+        if repo_id is None:
+            raise ValueError("hf_repo_id cannot be None")
         directory, _ = os.path.split(absolute_path)
-        assert isinstance(profile.hf_config_file, list)
-
+        if not profile.hf_config_file:
+            raise ValueError("hf_config_file cannot be None")
         for file_name in profile.hf_config_file:
             ModelDownloadManager._load_from_hf_hub(repo_id, file_name, directory)
 
