@@ -24,7 +24,7 @@ from typing import Dict, List, Tuple
 from ..utils.context import save_tmp_file
 from ..utils.detection_types import Requirement
 from ..utils.file_utils import get_pdfplumber_requirement, pdfplumber_available
-from ..utils.settings import names
+from ..utils.settings import LayoutType, ObjectTypes
 from .base import DetectionResult, PdfMiner
 
 if pdfplumber_available():
@@ -36,7 +36,7 @@ def _to_detect_result(word: Dict[str, str]) -> DetectionResult:
         box=[float(word["x0"]), float(word["top"]), float(word["x1"]), float(word["bottom"])],
         class_id=1,
         text=word["text"],
-        class_name=names.C.WORD,
+        class_name=LayoutType.word,
     )
 
 
@@ -69,6 +69,9 @@ class PdfPlumberTextDetector(PdfMiner):
 
     """
 
+    def __init__(self) -> None:
+        self.categories = {"1": LayoutType.word}
+
     def predict(self, pdf_bytes: bytes) -> List[DetectionResult]:
         """
         Call pdfminer.six and returns detected text as detection results
@@ -107,5 +110,5 @@ class PdfPlumberTextDetector(PdfMiner):
                 self._pdf_bytes = pdf_bytes
         return self._page.bbox[2], self._page.bbox[3]
 
-    def possible_categories(self) -> List[str]:
-        return [names.C.WORD]
+    def possible_categories(self) -> List[ObjectTypes]:
+        return [LayoutType.word]
