@@ -41,7 +41,7 @@ def maskrcnn_loss(mask_logits, fg_labels, fg_target_masks):
 
     # add some training visualizations to tensorboard
     with tf.name_scope("mask_viz"):
-        viz = tf.concat([fg_target_masks, mask_probs], axis=1)  # pylint: disable =E1123
+        viz = tf.concat([fg_target_masks, mask_probs], axis=1)
         viz = tf.expand_dims(viz, 3)
         viz = tf.cast(viz * 255, tf.uint8, name="viz")
         tf.summary.image("mask_truth|pred", viz, max_outputs=10)
@@ -88,9 +88,7 @@ def maskrcnn_upXconv_head(feature, num_category, num_convs, norm=None, **kwargs)
             l = Conv2D(f"fcn{k}", l, cfg.MRCNN.HEAD_DIM, 3, activation=tf.nn.relu)
             if norm is not None:
                 l = GroupNorm(f"gn{k}", l)
-        l = Conv2DTranspose(
-            "deconv", l, cfg.MRCNN.HEAD_DIM, 2, strides=2, activation=tf.nn.relu
-        )
+        l = Conv2DTranspose("deconv", l, cfg.MRCNN.HEAD_DIM, 2, strides=2, activation=tf.nn.relu)
         l = Conv2D("conv", l, num_category, 1, kernel_initializer=tf.random_normal_initializer(stddev=0.001))
     return l
 
@@ -121,7 +119,5 @@ def unpackbits_masks(masks):
     assert masks.dtype == tf.uint8, masks
     bits = tf.constant((128, 64, 32, 16, 8, 4, 2, 1), dtype=tf.uint8)
     unpacked = tf.bitwise.bitwise_and(tf.expand_dims(masks, -1), bits) > 0
-    unpacked = tf.reshape(
-        unpacked, tf.concat([tf.shape(masks)[:-1], [8 * tf.shape(masks)[-1]]], axis=0)  # pylint: disable =E1123
-    )
+    unpacked = tf.reshape(unpacked, tf.concat([tf.shape(masks)[:-1], [8 * tf.shape(masks)[-1]]], axis=0))
     return unpacked
