@@ -20,17 +20,17 @@ Module for cell detection pipeline component
 """
 
 from collections import Counter, defaultdict
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Mapping, Optional, Union
 
 from ..datapoint.image import Image
 from ..extern.base import DetectionResult, ObjectDetector, PdfMiner
 from ..utils.detection_types import JsonDict
-from ..utils.settings import names
+from ..utils.settings import ObjectTypes, Relationships
 from .base import PredictorPipelineComponent
 from .registry import pipeline_component_registry
 
 
-class DetectResultGenerator:  # pylint: disable=R0903
+class DetectResultGenerator:
     """
     Use: class: `DetectResultGenerator` to refine raw detection results.
 
@@ -41,7 +41,11 @@ class DetectResultGenerator:  # pylint: disable=R0903
     """
 
     def __init__(
-        self, categories: Dict[str, str], image_width: float, image_height: float, group_categories: List[List[str]]
+        self,
+        categories: Mapping[str, ObjectTypes],
+        image_width: float,
+        image_height: float,
+        group_categories: List[List[str]],
     ) -> None:
         """
         :param categories: The dict of all possible detection categories
@@ -139,9 +143,8 @@ class SubImageLayoutService(PredictorPipelineComponent):
         self.sub_image_name = sub_image_names
         self.dummy_generator_cls = None
         if add_dummy_detection:
-            assert category_id_mapping is not None, (
-                "Using DetectResult dummy generator requires passing a " "category_id_mapping"
-            )
+            if category_id_mapping is None:
+                raise ValueError("Using DetectResult dummy generator requires passing a category_id_mapping")
             self.dummy_generator_cls = DetectResultGenerator
             group_categories_dict = defaultdict(list)
             for group in category_id_mapping.items():
@@ -159,7 +162,8 @@ class SubImageLayoutService(PredictorPipelineComponent):
         """
         sub_image_anns = dp.get_annotation_iter(category_names=self.sub_image_name)
         for sub_image_ann in sub_image_anns:
-            assert sub_image_ann.image is not None
+            if sub_image_ann.image is None:
+                raise ValueError("sub_image_ann.image is None, but must be an image")
             detect_result_list = self.predictor.predict(sub_image_ann.image.image)
             if self.has_dummy_generator():
                 if hasattr(self.predictor, "categories"):
@@ -208,7 +212,7 @@ class SubImageLayoutService(PredictorPipelineComponent):
                 ("image_annotations", self.predictor.possible_categories()),
                 ("sub_categories", {}),
                 # implicit setup of relations by using set_image_annotation with explicit annotation_id
-                ("relationships", {parent: {names.C.CHILD} for parent in self.sub_image_name}),
+                ("relationships", {parent: {Relationships.child} for parent in self.sub_image_name}),
                 ("summaries", []),
             ]
         )
