@@ -31,7 +31,7 @@ from ..mapper.misc import to_image
 from ..utils.detection_types import Pathlike
 from ..utils.fs import maybe_path_or_pdf
 from ..utils.logger import logger
-from ..utils.settings import names
+from ..utils.settings import LayoutType
 from .base import Pipeline, PipelineComponent, PredictorPipelineComponent
 from .common import PageParsingService
 
@@ -54,9 +54,9 @@ class DoctectionPipe(Pipeline):
             self.page_parser = pipeline_component_list.pop()
         else:
             self.page_parser = PageParsingService(
-                text_container=names.C.WORD,
-                floating_text_block_names=[names.C.TEXT, names.C.TITLE, names.C.LIST],
-                text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST, names.C.TAB],
+                text_container=LayoutType.word,
+                floating_text_block_names=[LayoutType.text, LayoutType.title, LayoutType.list],
+                text_block_names=[LayoutType.title, LayoutType.text, LayoutType.list, LayoutType.table],
             )
         assert all(
             isinstance(element, (PipelineComponent, PredictorPipelineComponent)) for element in pipeline_component_list
@@ -65,16 +65,18 @@ class DoctectionPipe(Pipeline):
 
     def _entry(self, **kwargs: Union[str, DataFlow, bool, int, Pathlike, Union[str, List[str]]]) -> DataFlow:
         dataset_dataflow = kwargs.get("dataset_dataflow")
-
         path = kwargs.get("path")
-        assert path is not None or dataset_dataflow is not None, "pass either path or dataset_dataflow as argument"
+        if path is None and dataset_dataflow is None:
+            raise ValueError("Pass either path or dataset_dataflow as argument")
 
         shuffle = kwargs.get("shuffle", False)
-        assert isinstance(shuffle, bool)
+        if not isinstance(shuffle, bool):
+            raise TypeError(f"shuffle must be of type bool but is of type {type(shuffle)}")
 
         doc_path = None
         if path:
-            assert isinstance(path, (str, Path))
+            if not isinstance(path, (str, Path)):
+                raise TypeError("path must be of type PathOrStr")
             path_type = maybe_path_or_pdf(path)
             if path_type == 2:
                 doc_path = path
@@ -85,20 +87,27 @@ class DoctectionPipe(Pipeline):
         file_type = kwargs.get("file_type", [".jpg", ".png", ".tif"])
 
         max_datapoints = kwargs.get("max_datapoints")
-        assert isinstance(max_datapoints, (int, type(None)))
+        if not isinstance(max_datapoints, (int, type(None))):
+            raise TypeError(f"max_datapoints must be of type int, but is of type {type(max_datapoints)}")
+        df: DataFlow
 
         if isinstance(path, (str, Path)):
-            assert isinstance(file_type, (str, list))
+            if not isinstance(file_type, (str, list)):
+                raise TypeError(f"file_type must be of type string or list, but is of type {type(file_type)}")
             df = DoctectionPipe.path_to_dataflow(path, file_type, shuffle=shuffle)
         if isinstance(doc_path, (str, Path)):
             df = DoctectionPipe.doc_to_dataflow(
                 path=doc_path, max_datapoints=int(max_datapoints) if max_datapoints is not None else None
             )
-        if dataset_dataflow is not None:
+        if dataset_dataflow is not None and isinstance(dataset_dataflow, DataFlow):
             df = dataset_dataflow
 
         def _proto_process(dp: Image) -> Image:
-            logger.info("processing %s", dp.file_name)
+            if path is None:
+                path_tmp = doc_path
+            else:
+                path_tmp = path  # type: ignore
+            logger.info("Processing %s", dp.file_name, {"path": path_tmp, "df": path_tmp, "file_name": dp.file_name})
             return dp
 
         df = MapData(df, _proto_process)
@@ -121,7 +130,8 @@ class DoctectionPipe(Pipeline):
         :param shuffle: Shuffle file names in order to stream them randomly
         :return: dataflow
         """
-        assert os.path.isdir(path), f"{path} not a directory"
+        if not os.path.isdir(path):
+            raise NotADirectoryError(f"{path} not a directory")
         df = SerializerFiles.load(path, file_type, max_datapoints, shuffle)
 
         def _to_image(dp: str) -> Optional[Image]:
@@ -141,7 +151,9 @@ class DoctectionPipe(Pipeline):
         :param max_datapoints: max number of datapoints to consider
         :return: dataflow
         """
-        assert os.path.isfile(path), f"{path} not a file"
+        if not os.path.isfile(path):
+            raise FileExistsError(f"{path} not a file")
+
         df = SerializerPdfDoc.load(path, max_datapoints=max_datapoints)
 
         @curry
@@ -173,7 +185,7 @@ class DoctectionPipe(Pipeline):
         """
 
         output = kwargs.get("output", "page")
-        assert output in ["page", "image", "dict"], "output must be either page image or dict"
+        assert output in ("page", "image", "dict"), "output must be either page image or dict"
         df = self._entry(**kwargs)
         df = self._build_pipe(df)
         if output == "page":
