@@ -206,7 +206,7 @@ def train_d2_faster_rcnn(
     augment_list = [ResizeShortestEdge(cfg.INPUT.MIN_SIZE_TRAIN, cfg.INPUT.MAX_SIZE_TRAIN), RandomFlip()]
     mapper = DatasetMapper(is_train=True, augmentations=augment_list, image_format="BGR")
 
-    logger.info("Config: ------------------------------------------\n %s", str(cfg))
+    logger.info("Config: \n %s", str(cfg), cfg)
     trainer = D2Trainer(cfg, dataset, mapper)
     trainer.resume_or_load()
 
