@@ -16,6 +16,7 @@ from .pdf_utils import *
 from .settings import *
 from .systools import *
 from .tqdm import *
+from .transform import *
 from .utils import *
 from .viz import *
 
@@ -48,7 +49,9 @@ def _global_import(
 _global_import("file_utils", suffix=("_available", "_requirement"))
 _global_import("metacfg", prefix=("set_config_by_yaml", "save_config_to_yaml", "config_to_cli_str"))
 _global_import("utils", prefix=("delete_keys_from_dict", "split_string", "string_to_dict"))
-_global_import("settings", prefix="names")
+_global_import(
+    "settings", suffix=("Type", "TokenClasses", "BioTag", "TokenClassWithTag", "Relationships", "Languages", "get_type")
+)
 
 # pylint: disable=undefined-variable
 __all__.extend(context.__all__)  # type: ignore
@@ -58,5 +61,6 @@ __all__.extend(["logger", "set_logger_dir", "auto_set_dir", "get_logger_dir"])
 __all__.extend(pdf_utils.__all__)  # type: ignore
 __all__.extend(systools.__all__)  # type: ignore
 __all__.extend(["get_tqdm"])
+__all__.extend(transform.__all__)  # type: ignore
 __all__.extend(viz.__all__)  # type: ignore
 # pylint: enable=undefined-variable
