@@ -25,15 +25,16 @@ import os
 from base64 import b64encode
 from io import BytesIO
 from pathlib import Path
-from typing import Callable, Literal, Optional, Protocol, Sequence, Union, overload
+from typing import Callable, Literal, Optional, Protocol, Union, overload
 from urllib.request import urlretrieve
 
 from cv2 import IMREAD_COLOR, imread
 
-from ..utils.pdf_utils import get_pdf_file_reader, get_pdf_file_writer
 from .detection_types import ImageType, JsonDict, Pathlike
 from .logger import logger
+from .pdf_utils import get_pdf_file_reader, get_pdf_file_writer
 from .tqdm import get_tqdm
+from .utils import FileExtensionError, is_file_extension
 
 __all__ = [
     "load_image_from_file",
@@ -44,6 +45,7 @@ __all__ = [
     "mkdir_p",
     "is_file_extension",
     "load_json",
+    "FileExtensionError",
 ]
 
 
@@ -124,19 +126,6 @@ def download(url: str, directory: Pathlike, file_name: Optional[str] = None, exp
     return f_path
 
 
-def is_file_extension(file_name: Pathlike, extension: Union[str, Sequence[str]]) -> bool:
-    """
-    Check if a given file name has a given extension
-
-    :param file_name: the file name, either full along with path or as stand alone
-    :param extension: the extension of the file. Must add a dot (.)
-    :return: True/False
-    """
-    if isinstance(extension, str):
-        return os.path.splitext(file_name)[-1].lower() == extension
-    return os.path.splitext(file_name)[-1].lower() in extension
-
-
 @overload
 def load_image_from_file(path: Pathlike, type_id: Literal["np"] = "np") -> Optional[ImageType]:
     ...
@@ -193,7 +182,7 @@ def load_bytes_from_pdf_file(path: Pathlike) -> bytes:
     return buffer.getvalue()
 
 
-class LoadImageFunc(Protocol):  # pylint: disable = R0903
+class LoadImageFunc(Protocol):
     """
     Protocol for typing load_image_from_file
     """
