@@ -18,16 +18,19 @@
 """
 Testing the module dataflow.custom
 """
-from typing import Any, List
+from typing import Any, List, Union
+from pytest import mark
 
 from deepdoctection.dataflow import CacheData, CustomDataFromList
 
 
+@mark.basic
 def test_dataflow_cached_in_list(datapoint_list: List[Any]) -> None:
     """
     Testing CacheData get_cache method.
     """
     # Arrange
+    df: Union[CustomDataFromList, CacheData]
     df = CustomDataFromList(datapoint_list)
 
     # Act
@@ -39,11 +42,13 @@ def test_dataflow_cached_in_list(datapoint_list: List[Any]) -> None:
     assert set(df_list) == set(datapoint_list)
 
 
+@mark.basic
 def test_dataflow_from_list_with_max_datapoint(datapoint_list: List[Any]) -> None:
     """
     Testing CustomDataFromList max_datapoint argument
     """
     # Act
+    df: Union[CustomDataFromList, CacheData]
     df = CustomDataFromList(datapoint_list, max_datapoints=3)
     df = CacheData(df)
     df.reset_state()
