@@ -29,7 +29,7 @@ class TestPdfPlumberTextDetector:
     """
 
     @staticmethod
-    @mark.all
+    @mark.requires_tf_or_pt
     def test_pdf_plumber_detector_predicts_image(pdf_bytes: bytes) -> None:
         """
         PdfPlumber returns words from pdf_bytes correctly
@@ -47,7 +47,7 @@ class TestPdfPlumberTextDetector:
         assert detect_results_list[1].text == "Simple"
 
     @staticmethod
-    @mark.all
+    @mark.requires_tf_or_pt
     def test_pdf_plumber_detector_returns_width_height(pdf_bytes: bytes, pdf_bytes_page_2: bytes) -> None:
         """
         PdfPlumber returns pdf width and height correctly
@@ -68,3 +68,4 @@ class TestPdfPlumberTextDetector:
         width, height = pdf_text_predictor.get_width_height(pdf_bytes_page_2)
         assert width == 1112
         assert height == 1792
+
