@@ -24,10 +24,20 @@ from unittest.mock import MagicMock, patch
 import pytest
 
 from deepdoctection.extern.base import DetectionResult
-from deepdoctection.extern.tessocr import TesseractOcrDetector
+from deepdoctection.extern.tessocr import TesseractOcrDetector, tesseract_line_to_detectresult
 from deepdoctection.utils.detection_types import ImageType
 from deepdoctection.utils.file_utils import TesseractNotFound
+
 from tests.data import Annotations
+from .data import WORD_RESULTS
+
+
+@pytest.fixture(name="word_result_list_same_line")
+def fixture_pdf_bytes_page_2() -> List[DetectionResult]:
+    """
+    fixture list of word results. Words are in the same line
+    """
+    return WORD_RESULTS
 
 
 def get_mock_word_results(
@@ -45,6 +55,7 @@ class TestTesseractOcrDetector:
     """
 
     @staticmethod
+    @pytest.mark.basic
     @patch("deepdoctection.utils.subprocess.check_output", MagicMock(side_effect=OSError))
     def test_tesseract_ocr_raises_tesseract_not_found_error_when_dependencies_not_satisfied(
         path_to_tesseract_yaml: str,
@@ -59,6 +70,7 @@ class TestTesseractOcrDetector:
             TesseractOcrDetector(path_yaml=path_to_tesseract_yaml)
 
     @staticmethod
+    @pytest.mark.basic
     @patch("deepdoctection.utils.file_utils.get_tesseract_version", MagicMock(return_value=3.15))
     @patch("deepdoctection.extern.tessocr.predict_text", MagicMock(side_effect=get_mock_word_results))
     def test_tesseract_ocr_predicts_image(path_to_tesseract_yaml: str, np_image: ImageType) -> None:
@@ -74,3 +86,20 @@ class TestTesseractOcrDetector:
 
         # Assert
         assert len(results) == 2
+
+
+@pytest.mark.basic
+def test_line_detect_result_returns_line(word_result_list_same_line: List[DetectionResult]) -> None:
+    """
+    Testing tesseract_line_to_detectresult generates Line DetectionResult
+    """
+
+    # Act
+    detect_result_list = tesseract_line_to_detectresult(word_result_list_same_line)
+
+    # Assert
+    assert len(detect_result_list) == 3
+    line_detect_result = detect_result_list[2]
+    assert line_detect_result.box == [10.0, 10.0, 38.0, 24.0]
+    assert line_detect_result.class_id == 2
+    assert line_detect_result.text == "foo bak"
