@@ -21,7 +21,7 @@ Some datapoint samples in a separate module
 
 from collections import namedtuple
 from dataclasses import dataclass
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Mapping, Optional, Union
 
 import numpy as np
 
@@ -36,7 +36,18 @@ from deepdoctection.datapoint import (
 from deepdoctection.datasets.info import DatasetCategories
 from deepdoctection.extern.base import SequenceClassResult, TokenClassResult
 from deepdoctection.utils.detection_types import ImageType, JsonDict
-from deepdoctection.utils.settings import names
+from deepdoctection.utils.settings import (
+    BioTag,
+    CellType,
+    DatasetType,
+    LayoutType,
+    ObjectTypes,
+    TableType,
+    TokenClasses,
+    TokenClassWithTag,
+    get_type,
+)
+from tests.data import TestType
 
 _SAMPLE_COCO = {
     "file_name": "/test/path/PMC5447509_00002.jpg",
@@ -657,7 +668,13 @@ class DatapointCoco:
     dp = _SAMPLE_COCO
     white_image: ImageType = np.ones((794, 596, 3), dtype=np.int32) * 255  # type: ignore
     white_image_string = convert_np_array_to_b64(white_image)
-    categories = {"1": "text", "2": "title", "3": "table", "4": "figure", "5": "list"}
+    categories = {
+        "1": LayoutType.text,
+        "2": LayoutType.title,
+        "3": LayoutType.table,
+        "4": LayoutType.figure,
+        "5": LayoutType.list,
+    }
     first_ann_box = Box(37.59, 360.34, 251.07, 41.36)
 
     def get_white_image(self, path: str, type_id: str = "np") -> Optional[Union[str, ImageType]]:
@@ -709,13 +726,13 @@ class DatapointCoco:
 
 
 @dataclass
-class DatapointPubtabnet:  # pylint: disable=R0904
+class DatapointPubtabnet:
     """
     Class for datapoint in pubtabnet annotation format
     """
 
     dp = _SAMPLE_PUBTABNET
-    categories = {"1": "CELL", "2": "ITEM", "3": "TABLE", "4": "WORD"}
+    categories = {"1": LayoutType.cell, "2": TableType.item, "3": LayoutType.table, "4": LayoutType.word}
     categories_as_names = {v: k for k, v in categories.items()}
     first_ann_box = Box(475, 162, 10, 9)
     white_image: ImageType = np.ones((1334, 996, 3), dtype=np.int32) * 255  # type: ignore
@@ -763,11 +780,11 @@ class DatapointPubtabnet:  # pylint: disable=R0904
             return "1"
         return self.categories["1"]
 
-    def get_first_ann_sub_category_header_name(self) -> str:  # pylint: disable=R0201
+    def get_first_ann_sub_category_header_name(self) -> ObjectTypes:  # pylint: disable=R0201
         """
         category_name of sub category
         """
-        return "BODY"
+        return CellType.body
 
     def get_last_ann_category_name(self) -> str:
         """
@@ -775,11 +792,11 @@ class DatapointPubtabnet:  # pylint: disable=R0904
         """
         return self.categories["1"]
 
-    def get_last_ann_sub_category_header_name(self) -> str:  # pylint: disable=R0201
+    def get_last_ann_sub_category_header_name(self) -> ObjectTypes:  # pylint: disable=R0201
         """
         category_name of sub category
         """
-        return "HEAD"
+        return CellType.header
 
     def get_last_ann_sub_category_row_number_id(self) -> str:  # pylint: disable=R0201
         """
@@ -879,7 +896,13 @@ class DatapointProdigy:
     """
 
     dp = _SAMPLE_PRODIGY
-    categories = {"TEXT": "1", "TITLE": "2", "TABLE": "3", "FIGURE": "4", "LIST": "5"}
+    categories = {
+        LayoutType.text: "1",
+        LayoutType.title: "2",
+        LayoutType.table: "3",
+        LayoutType.figure: "4",
+        LayoutType.list: "5",
+    }
     first_ann_box = Box(1, 2.7, 14, 26.3)
 
     def get_width(self, image_loaded: bool) -> float:
@@ -910,13 +933,13 @@ class DatapointProdigy:
         """
         return self.first_ann_box
 
-    def get_first_ann_category(self, as_index: bool = True) -> str:
+    def get_first_ann_category(self, as_index: bool = True) -> Union[ObjectTypes, str]:
         """
         category_name or category_id
         """
         if as_index:
-            return self.categories["TABLE"]
-        return "TABLE"
+            return self.categories[LayoutType.table]
+        return LayoutType.table
 
 
 class DatapointImage:
@@ -938,15 +961,15 @@ class DatapointImage:
         self.dict_text: str = "sample.png"
         self.len_spans: int = 2
         self.first_span: JsonDict = {
-            "label": "FOO",
-            "annotation_id": "2a761d95-14f8-3a03-a5ee-f64c1130cb80",
+            "label": TestType.FOO,
+            "annotation_id": "ec7e5bca-b4f4-3272-8952-35a500663131",
             "score": 0.53,
             "type": "rect",
             "points": [[2.6, 3.7], [2.6, 5.7], [4.6, 5.7], [4.6, 3.7]],
         }
         self.second_span: JsonDict = {
-            "label": "BAK",
-            "annotation_id": "e1dad126-ced5-3a1b-a8ae-6af5cf067b1f",
+            "label": TestType.BAK,
+            "annotation_id": "b8cb337a-de1b-3bfd-bb36-603d852104f2",
             "score": 0.99,
             "type": "rect",
             "points": [[16.6, 26.6], [16.6, 30.6], [30.6, 30.6], [30.6, 26.6]],
@@ -972,7 +995,7 @@ class DatapointImage:
                 "score": 0.99,
             },
         ]
-        self.categories = DatasetCategories(init_categories=["FOO", "BAK"])
+        self.categories = DatasetCategories(init_categories=[get_type("FOO"), get_type("BAK")])
         self.tp_frcnn_training: JsonDict = {
             "image": _img_np,
             "gt_boxes": np.asarray([[2.6, 3.7, 4.6, 5.7], [16.6, 26.6, 30.6, 30.6]]).astype("float32"),
@@ -1056,11 +1079,11 @@ class DatapointImage:
         Image with summary "BAK" and CategoryAnnotation "FOO"
         """
         self.image.summary = SummaryAnnotation()
-        self.image.summary.dump_sub_category("BAK", CategoryAnnotation(category_name="FOO", category_id="1"))
+        self.image.summary.dump_sub_category(get_type("BAK"), CategoryAnnotation(category_name="FOO", category_id="1"))
         return self.image
 
 
-class DatapointPageDict:  # pylint: disable=R0903
+class DatapointPageDict:
     """
     Page object as dict
     """
@@ -1764,30 +1787,35 @@ class DatapointXfund:
 
     dp = _SAMPLE_XFUND["documents"][0]
 
-    category_names_mapping = {"other": names.C.O, "question": names.C.Q, "answer": names.C.A, "header": names.C.HEAD}
+    category_names_mapping = {
+        "other": TokenClasses.other,
+        "question": TokenClasses.question,
+        "answer": TokenClasses.answer,
+        "header": TokenClasses.header,
+    }
     categories_dict_name_as_key = {
-        "B-ANSWER": "1",
-        "B-HEAD": "2",
-        "B-QUESTION": "3",
-        "E-ANSWER": "4",
-        "E-HEAD": "5",
-        "E-QUESTION": "6",
-        "I-ANSWER": "7",
-        "I-HEAD": "8",
-        "I-QUESTION": "9",
-        "O": "10",
-        "S-ANSWER": "11",
-        "S-HEAD": "12",
-        "S-QUESTION": "13",
+        get_type("B-ANSWER"): "1",
+        get_type("B-HEADER"): "2",
+        get_type("B-QUESTION"): "3",
+        get_type("E-ANSWER"): "4",
+        get_type("E-HEADER"): "5",
+        get_type("E-QUESTION"): "6",
+        get_type("I-ANSWER"): "7",
+        get_type("I-HEADER"): "8",
+        get_type("I-QUESTION"): "9",
+        get_type("O"): "10",
+        get_type("S-ANSWER"): "11",
+        get_type("S-HEADER"): "12",
+        get_type("S-QUESTION"): "13",
     }
     ner_token_to_id_mapping = {
-        names.NER.B_A: "1",
-        names.NER.B_H: "2",
-        names.NER.B_Q: "3",
-        names.NER.I_A: "4",
-        names.NER.I_H: "5",
-        names.NER.I_Q: "6",
-        names.NER.O: "7",
+        TokenClassWithTag.b_answer: "1",
+        TokenClassWithTag.b_header: "2",
+        TokenClassWithTag.b_question: "3",
+        TokenClassWithTag.i_answer: "4",
+        TokenClassWithTag.i_header: "5",
+        TokenClassWithTag.i_question: "6",
+        BioTag.outside: "7",
     }
     layout_input = {
         "image_ids": ["t74dfkh3-12gr-17d9-8e41-c4d134c0uzo4"],
@@ -1889,17 +1917,17 @@ class DatapointXfund:
         "width": 1000,
         "height": 1000,
         "ann_ids": [
-            "0d0600cf-df94-34fa-9b30-5ecbbd1b36ab",
-            "34bb95dc-7fe6-3982-9dd5-e49d362b3fd7",
-            "a77dfce6-32ff-31b4-8e39-cbbdd4c0acf1",
+            "440c677a-05ca-33a5-8e61-dd2a9724367d",
+            "75d7e019-4951-342b-b073-27aba447e7e8",
+            "0b07ba23-6f2c-3c73-ab62-cb1bd891ae7f",
         ],
         "words": ["Akademisches", "Auslandsamt", "Bewerbungsformular"],
         "bbox": [[325.0, 184.0, 578.0, 230.0], [586.0, 186.0, 834.0, 232.0], [1058.0, 413.0, 1701.0, 482.0]],
-        "dataset_type": names.DS.TYPE.TOK,
+        "dataset_type": DatasetType.token_classification,
         "labels": [6, 6, 1],
     }
 
-    def get_category_names_mapping(self) -> Dict[str, str]:
+    def get_category_names_mapping(self) -> Mapping[str, ObjectTypes]:
         """
         category_names_mapping
         """
@@ -1942,14 +1970,14 @@ class DatapointXfund:
         """
         categories semantics
         """
-        return ["FOO"]
+        return [TestType.FOO]
 
     @staticmethod
     def get_categories_bio() -> List[str]:
         """
         categories bio
         """
-        return ["B", "I", "O"]
+        return [BioTag.begin, BioTag.inside, BioTag.outside]
 
     @staticmethod
     def get_token_class_names() -> List[str]:
@@ -1957,31 +1985,31 @@ class DatapointXfund:
         token class names
         """
         return [
-            "B-FOO",
-            "I-FOO",
-            "I-FOO",
-            "B-FOO",
-            "I-FOO",
-            "O",
-            "I-FOO",
-            "I-FOO",
-            "I-FOO",
-            "B-FOO",
-            "B-FOO",
-            "B-FOO",
-            "I-FOO",
-            "O",
-            "I-FOO",
-            "B-FOO",
-            "I-FOO",
-            "I-FOO",
+            TokenClassWithTag.b_header,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.b_header,
+            TokenClassWithTag.i_header,
+            BioTag.outside,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.b_header,
+            TokenClassWithTag.b_header,
+            TokenClassWithTag.b_header,
+            TokenClassWithTag.i_header,
+            BioTag.outside,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.b_header,
+            TokenClassWithTag.i_header,
+            TokenClassWithTag.i_header,
         ]
 
-    def get_categories_dict_names_as_key(self) -> Dict[str, str]:
+    def get_categories_dict_names_as_key(self) -> Dict[ObjectTypes, str]:
         """categories dict names as key"""
         return self.categories_dict_name_as_key
 
-    def get_net_token_to_id_mapping(self) -> Dict[str, str]:
+    def get_net_token_to_id_mapping(self) -> Dict[ObjectTypes, str]:
         """token to id mapping"""
         return self.ner_token_to_id_mapping
 
@@ -2015,18 +2043,23 @@ class IIITar13KJson:
         ],
     }
 
-    categories_name_as_keys = {names.C.TAB: "1", names.C.LOGO: "2", names.C.FIG: "3", names.C.SIGN: "4"}
+    categories_name_as_keys = {
+        LayoutType.table: "1",
+        LayoutType.logo: "2",
+        LayoutType.figure: "3",
+        LayoutType.signature: "4",
+    }
     category_names_mapping = {
-        "natural_image": names.C.FIG,
-        "figure": names.C.FIG,
-        "logo": names.C.LOGO,
-        "signature": names.C.SIGN,
-        "table": names.C.TAB,
+        "natural_image": LayoutType.figure,
+        "figure": LayoutType.figure,
+        "logo": LayoutType.logo,
+        "signature": LayoutType.signature,
+        "table": LayoutType.table,
     }
 
     first_ann_box = Box(ulx=127, uly=202, w=1006 - 127, h=580 - 202)
 
-    def get_category_names_mapping(self) -> Dict[str, str]:
+    def get_category_names_mapping(self) -> Mapping[str, ObjectTypes]:
         """
         category_names_mapping
         """
@@ -2061,10 +2094,10 @@ class IIITar13KJson:
         """
         first annotation category name
         """
-        return names.C.TAB
+        return LayoutType.table
 
-    def get_categories_name_as_keys(self) -> Dict[str, str]:
+    def get_categories_name_as_keys(self) -> Mapping[ObjectTypes, str]:
         """
         categories name as keys
         """
-        return self.categories_name_as_keys
+        return self.categories_name_as_keys  # type: ignore
