@@ -21,18 +21,21 @@ Testing module pipe.segment
 
 from typing import List
 
+from pytest import mark
+
 from deepdoctection.datapoint import BoundingBox, CategoryAnnotation, Image
 from deepdoctection.pipe.segment import TableSegmentationService, stretch_items, tile_tables_with_items_per_table
-from deepdoctection.utils.settings import names
+from deepdoctection.utils.settings import CellType, LayoutType
 
 
+@mark.basic
 def test_stretch_items(dp_image_tab_cell_item: Image, dp_image_item_stretched: Image) -> None:
     """test stretch_items"""
     # Arrange
     dp = dp_image_tab_cell_item
     dp_expected = dp_image_item_stretched
-    table_name = names.C.TAB
-    item_names = [names.C.ROW, names.C.COL]
+    table_name = LayoutType.table
+    item_names = [LayoutType.row, LayoutType.column]
 
     # Act
     dp = stretch_items(dp, table_name, item_names[0], item_names[1], 0.001, 0.001)
@@ -90,6 +93,7 @@ class TestTableSegmentationService:
             self._remove_iou_threshold_cols,
         )
 
+    @mark.basic
     def test_pass_datapoint(self, dp_image_tab_cell_item: Image, dp_image_fully_segmented: Image) -> None:
         """test pass_datapoint"""
 
@@ -123,27 +127,28 @@ class TestTableSegmentationService:
 
         for el in zip(cells, cells_expected):
             cell, cell_expected = el[0], el[1]
-            row_sub_cat = cell.get_sub_category(names.C.RN)
-            row_sub_cat_expected = cell_expected.get_sub_category(names.C.RN)
+            row_sub_cat = cell.get_sub_category(CellType.row_number)
+            row_sub_cat_expected = cell_expected.get_sub_category(CellType.row_number)
             assert row_sub_cat.category_name == row_sub_cat_expected.category_name
             assert row_sub_cat.category_id == row_sub_cat_expected.category_id
 
-            col_sub_cat = cell.get_sub_category(names.C.CN)
-            col_sub_cat_expected = cell_expected.get_sub_category(names.C.CN)
+            col_sub_cat = cell.get_sub_category(CellType.column_number)
+            col_sub_cat_expected = cell_expected.get_sub_category(CellType.column_number)
             assert col_sub_cat.category_name == col_sub_cat_expected.category_name
             assert col_sub_cat.category_id == col_sub_cat_expected.category_id
 
-            rs_sub_cat = cell.get_sub_category(names.C.RS)
-            rs_sub_cat_expected = cell_expected.get_sub_category(names.C.RS)
+            rs_sub_cat = cell.get_sub_category(CellType.row_span)
+            rs_sub_cat_expected = cell_expected.get_sub_category(CellType.row_span)
             assert rs_sub_cat.category_name == rs_sub_cat_expected.category_name
             assert rs_sub_cat.category_id == rs_sub_cat_expected.category_id
 
-            cs_sub_cat = cell.get_sub_category(names.C.CS)
-            cs_sub_cat_expected = cell_expected.get_sub_category(names.C.CS)
+            cs_sub_cat = cell.get_sub_category(CellType.column_span)
+            cs_sub_cat_expected = cell_expected.get_sub_category(CellType.column_span)
             assert cs_sub_cat.category_name == cs_sub_cat_expected.category_name
             assert cs_sub_cat.category_id == cs_sub_cat_expected.category_id
 
 
+@mark.basic
 def test_tile_tables_with_items_per_table(
     dp_image_item_stretched: Image,
     row_box_tiling_table: List[BoundingBox],
@@ -155,23 +160,23 @@ def test_tile_tables_with_items_per_table(
 
     # Arrange
     dp = dp_image_item_stretched
-    rows = dp.get_annotation_iter(category_names=names.C.ROW)
-    cols = dp.get_annotation_iter(category_names=names.C.COL)
+    rows = dp.get_annotation_iter(category_names=LayoutType.row)
+    cols = dp.get_annotation_iter(category_names=LayoutType.column)
 
     for row, col, row_sub_cat, col_sub_cat in zip(rows, cols, row_sub_cats, col_sub_cats):
-        row.dump_sub_category(names.C.RN, row_sub_cat)
-        col.dump_sub_category(names.C.CN, col_sub_cat)
+        row.dump_sub_category(CellType.row_number, row_sub_cat)
+        col.dump_sub_category(CellType.column_number, col_sub_cat)
 
-    table = dp.get_annotation(category_names=names.C.TAB)
-    item_names = [names.C.ROW, names.C.COL]  # row names must be before column name
+    table = dp.get_annotation(category_names=LayoutType.table)
+    item_names = [LayoutType.row, LayoutType.column]  # row names must be before column name
 
     # Act
     dp = tile_tables_with_items_per_table(dp, table[0], item_names[0])
     dp = tile_tables_with_items_per_table(dp, table[0], item_names[1])
 
     # Assert
-    rows = dp.get_annotation(category_names=names.C.ROW)
-    cols = dp.get_annotation(category_names=names.C.COL)
+    rows = dp.get_annotation(category_names=LayoutType.row)
+    cols = dp.get_annotation(category_names=LayoutType.column)
 
     assert rows[0].image is not None and rows[1].image is not None
     first_row_box = rows[0].image.get_embedding(dp.image_id)
@@ -216,6 +221,7 @@ class TestTableSegmentationServiceWhenTableFullyTiled:
             self._remove_iou_threshold_cols,
         )
 
+    @mark.basic
     def test_integration_pipeline_component(
         self, dp_image_tab_cell_item: Image, dp_image_fully_segmented_fully_tiled: Image
     ) -> None:
@@ -242,7 +248,9 @@ class TestTableSegmentationServiceWhenTableFullyTiled:
         assert len(cells) == len(cells_expected)
 
         for cell, cell_expected in zip(cells, cells_expected):
-            assert cell.get_sub_category(names.C.RN) == cell_expected.get_sub_category(names.C.RN)
-            assert cell.get_sub_category(names.C.CN) == cell_expected.get_sub_category(names.C.CN)
-            assert cell.get_sub_category(names.C.RS) == cell_expected.get_sub_category(names.C.RS)
-            assert cell.get_sub_category(names.C.CS) == cell_expected.get_sub_category(names.C.CS)
+            assert cell.get_sub_category(CellType.row_number) == cell_expected.get_sub_category(CellType.row_number)
+            assert cell.get_sub_category(CellType.column_number) == cell_expected.get_sub_category(
+                CellType.column_number
+            )
+            assert cell.get_sub_category(CellType.row_span) == cell_expected.get_sub_category(CellType.row_span)
+            assert cell.get_sub_category(CellType.column_span) == cell_expected.get_sub_category(CellType.column_span)
